Package: ggrefine
Title: Publication-Quality 'ggplot2' Themes
Version: 0.5.0
Authors@R: 
    person(given = "David", family = "Hodge", 
           email = "davidhodge931@gmail.com", 
           role = c("aut", "cre", "cph"), 
           comment = c(ORCID = "0000-0002-3868-7501"))
Description: Complete themes for publication-quality 'ggplot2' visualisation. 
    Also provides functions to modify these based on the positional axis scales 
    and orientation of a particular plot. 
License: MIT + file LICENSE
URL: https://github.com/davidhodge931/ggrefine,
        https://davidhodge931.github.io/ggrefine/
BugReports: https://github.com/davidhodge931/ggrefine/issues
Depends: R (>= 4.1.0)
Imports: blends, flexoki, ggplot2 (>= 4.0.0), grid, jumble, rlang,
        scales, viridis
Suggests: knitr, patchwork, rmarkdown, spelling
Encoding: UTF-8
Language: en-GB
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-07 04:37:20 UTC; david
Author: David Hodge [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-3868-7501>)
Maintainer: David Hodge <davidhodge931@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-07 05:00:02 UTC
Built: R 4.5.2; ; 2026-07-07 06:47:25 UTC; unix

Package: ggrefine
Title: Publication-Quality 'ggplot2' Themes
Version: 0.4.0
Authors@R: 
    person(given = "David", family = "Hodge", 
           email = "davidhodge931@gmail.com", 
           role = c("aut", "cre", "cph"), 
           comment = c(ORCID = "0000-0002-3868-7501"))
Description: Complete themes for publication-quality 'ggplot2' visualisation. 
    Also provides functions to modify these based on the positional axis scales 
    and focus of a particular plot. 
License: MIT + file LICENSE
URL: https://github.com/davidhodge931/ggrefine,
        https://davidhodge931.github.io/ggrefine/
BugReports: https://github.com/davidhodge931/ggrefine/issues
Depends: R (>= 4.1.0)
Imports: blends, flexoki, ggplot2, grid, jumble, rlang, scales, viridis
Suggests: knitr, patchwork, rmarkdown, spelling
Encoding: UTF-8
Language: en-GB
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-04 02:33:14 UTC; david
Author: David Hodge [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-3868-7501>)
Maintainer: David Hodge <davidhodge931@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-04 13:10:10 UTC
Built: R 4.6.0; ; 2026-05-04 17:20:15 UTC; unix

# Generated by roxygen2: do not edit by hand

export(classic_drift)
export(classic_drop)
export(classic_flow)
export(classic_keep)
export(minimal_drift)
export(minimal_drop)
export(minimal_flow)
export(minimal_keep)
export(modern_drift)
export(modern_drop)
export(modern_flow)
export(modern_keep)
export(theme_dark)
export(theme_ggplot2)
export(theme_grey)
export(theme_light)
export(void_drift)
export(void_drop)
export(void_flow)
export(void_keep)

<!-- README.md is generated from README.Rmd. Please edit that file -->

# ggrefine <a href="https://davidhodge931.github.io/ggrefine/"><img src="man/figures/logo.png" align="right" height="139" alt="ggrefine website" /></a>

<!-- badges: start -->

[![CRAN
status](https://www.r-pkg.org/badges/version/ggrefine)](https://CRAN.R-project.org/package=ggrefine)
<!-- badges: end -->

The objective of ggrefine is to provide some pretty ggplot2 complete
themes, and refine functions to tweak these easily based on the
particulars of a plot.

## Installation

Install from CRAN, or development version from
[GitHub](https://github.com/).

``` r
install.packages("ggrefine") 
pak::pak("davidhodge931/ggrefine")
```

## Theme

The themes are built to work with the refine functions - and can be
customised easily.

The `theme_grey` (and `theme_oat` functions differs from the other two
in that the `panel_grid_colour` by default is derived by applying a
multiply blend on the `panel_background_fill`.

To avoid namespace collisions, it is recommended to not load the
package, but instead refer to each function with the package name
(e.g. `ggrefine::theme_grey()`.

``` r
library(ggplot2)

p_base_light <- mpg |>
  ggplot(aes(x = hwy)) +
  geom_histogram(
    stat = "bin", shape = 21,
    colour = blends::multiply("#357BA2FF")
  ) +
  scale_y_continuous(expand = expansion(mult = c(0, 0.05)))

p_base_dark <- mpg |>
  ggplot(aes(x = hwy)) +
  geom_histogram(
    stat = "bin", shape = 21,
    colour = blends::screen("#357BA2FF")
  ) +
  scale_y_continuous(expand = expansion(mult = c(0, 0.05)))

p_light  <- p_base_light + ggrefine::theme_light() + labs(title = "ggrefine::theme_light")
p_dark  <- p_base_dark  + ggrefine::theme_dark() + labs(title = "ggrefine::theme_dark")
p_grey <- p_base_light + ggrefine::theme_grey() + labs(title = "ggrefine::theme_grey")
p_oat <- p_base_light + ggrefine::theme_oat() + labs(title = "ggrefine::theme_oat")

patchwork::wrap_plots(
  p_light,
  p_dark,
  p_grey,
  p_oat
)
```

<img src="man/figures/README-example-1.png" alt="" width="100%" />

## Refine

The other functions adjust gridlines and axis elements based on axis
types (`x_type` and `y_type`), which default to `"continuous"`.

``` r
set_theme(new = ggrefine::theme_grey())

p_continuous <- mpg |>
  ggplot(aes(x = displ, y = hwy)) +
  geom_point(shape = 21, colour = blends::multiply("#357BA2FF"))

p_discrete_x <- mpg |>
  ggplot(aes(x = drv, y = hwy)) +
  geom_jitter(shape = 21, colour = blends::multiply("#357BA2FF"))

p_discrete_y <- mpg |>
  ggplot(aes(x = hwy, y = drv)) +
  geom_jitter(shape = 21, colour = blends::multiply("#357BA2FF"))

patchwork::wrap_plots(
  p_continuous + ggrefine::classic() + labs(title = "ggrefine::classic"),
  p_discrete_x + ggrefine::classic(x_type = "discrete"),
  p_discrete_y + ggrefine::classic(y_type = "discrete"),
  p_continuous + ggrefine::modern() + labs(title = "ggrefine::modern"),
  p_discrete_x + ggrefine::modern(x_type = "discrete"),
  p_discrete_y + ggrefine::modern(y_type = "discrete"),
  p_continuous + ggrefine::hybrid() + labs(title = "ggrefine::hybrid"),
  p_discrete_x + ggrefine::hybrid(x_type = "discrete"),
  p_discrete_y + ggrefine::hybrid(y_type = "discrete"),
  p_continuous + ggrefine::minimal() + labs(title = "ggrefine::minimal"),
  p_discrete_x + ggrefine::minimal(x_type = "discrete"),
  p_discrete_y + ggrefine::minimal(y_type = "discrete"),
  p_continuous + ggrefine::void() + labs(title = "ggrefine::void"),
  p_discrete_x + ggrefine::void(x_type = "discrete"),
  p_discrete_y + ggrefine::void(y_type = "discrete"),
  p_continuous + ggrefine::none() + labs(title = "ggrefine::none"),
  p_discrete_x + ggrefine::none(x_type = "discrete"),
  p_discrete_y + ggrefine::none(y_type = "discrete"),
  ncol = 3
)
```

<img src="man/figures/README-unnamed-chunk-2-1.png" alt="" width="100%" />

## Other packages

This package is part of a group of related packages built to extend
[ggplot2](https://ggplot2.tidyverse.org).

<table>

<tr>

<td align="center">

<a href="https://davidhodge931.github.io/ggblanket/"><img src="https://raw.githubusercontent.com/davidhodge931/ggblanket/main/man/figures/logo.svg" width="120" alt="ggblanket"/></a>
</td>

<td align="center">

<a href="https://davidhodge931.github.io/ggrefine/"><img src="https://raw.githubusercontent.com/davidhodge931/ggrefine/main/man/figures/logo.svg" width="120" alt="ggrefine"/></a>
</td>

<td align="center">

<a href="https://davidhodge931.github.io/ggscribe/"><img src="https://raw.githubusercontent.com/davidhodge931/ggscribe/main/man/figures/logo.svg" width="120" alt="ggscribe"/></a>
</td>

<td align="center">

<a href="https://davidhodge931.github.io/ggwidth/"><img src="https://raw.githubusercontent.com/davidhodge931/ggwidth/main/man/figures/logo.svg" width="120" alt="ggwidth"/></a>
</td>

<td align="center">

<a href="https://davidhodge931.github.io/blends/"><img src="https://raw.githubusercontent.com/davidhodge931/blends/main/man/figures/logo.svg" width="120" alt="blends"/></a>
</td>

<td align="center">

<a href="https://davidhodge931.github.io/jumble/"><img src="https://raw.githubusercontent.com/davidhodge931/jumble/main/man/figures/logo.svg" width="120" alt="jumble"/></a>
</td>

</tr>

</table>

<!-- README.md is generated from README.Rmd. Please edit that file -->

# ggrefine <a href="https://davidhodge931.github.io/ggrefine/"><img src="man/figures/logo.png" align="right" height="139" alt="ggrefine website" /></a>

<!-- badges: start -->

[![CRAN
status](https://www.r-pkg.org/badges/version/ggrefine)](https://CRAN.R-project.org/package=ggrefine)
<!-- badges: end -->

The objective of ggrefine is to provide complete themes for
publication-quality ‘ggplot2’ visualisation. Functions are provided to
modify these based on the positional axis scales and orientation of a
particular plot.

## Installation

Install from CRAN, or development version from
[GitHub](https://github.com/).

``` r
install.packages("ggrefine") 
pak::pak("davidhodge931/ggrefine")
```

## Theme

The themes are built to work with the refine functions in that they have
all axis and panel grid elements.

They can also be customised easily.

The `theme_grey` function has a smart `panel_grid_colour` default that
is derived from the `panel_background_fill`.

To ensure ggrefine `theme_*` functions are preferred over ggplot2
functions:

- run `library(ggrefine)` after the ggplot2 library is loaded, or
- use `conflicted::conflict_prefer_all(winner = "ggrefine")`, or
- do not load ggrefine, but instead use `ggrefine::theme_grey()` etc.

``` r
library(ggplot2)
library(ggrefine)

p_base_light <- mpg |>
  ggplot(aes(x = hwy)) +
  geom_histogram(
    stat = "bin", shape = 21,
    colour = blends::multiply("#357BA2FF")
  ) +
  scale_y_continuous(expand = expansion(mult = c(0, 0.05)))

p_base_dark <- mpg |>
  ggplot(aes(x = hwy)) +
  geom_histogram(
    stat = "bin", shape = 21,
    colour = blends::screen("#357BA2FF")
  ) +
  scale_y_continuous(expand = expansion(mult = c(0, 0.05)))

p_light  <- p_base_light + theme_light() + labs(title = "theme_light")
p_dark  <- p_base_dark  + theme_dark() + labs(title = "theme_dark")
p_grey <- p_base_light + theme_grey() + labs(title = "theme_grey")
p_ggplot2 <- p_base_light + theme_grey(panel_grid_colour = "white") + 
  labs(title = "theme_ggplot")

patchwork::wrap_plots(
  p_light,
  p_dark,
  p_grey,
  p_ggplot2
)
```

<img src="man/figures/README-example-1.png" alt="" width="100%" />

## Refine

A series of refine functions are provided.

The premise is that it is useful to set themes that have all axis and
panel grid elements - and then adjust depending on the positional axis
scales and orientation of a particular plot.

The refine functions are organised and named by:

- axis: `classic_*`, `modern_*`, `minimal_*`, and `void_*`.
- panel grid: `*_drift`, `*_flow`, `*_drop`, `*_keep`.

These functions then remove or not particular axis and panel grid
components for different positional scales (and the intended orientation
of the plot).

``` r
set_theme(new = theme_light(
  panel_grid_colour = jumble::grey,
  axis_line_colour = jumble::red,
))

p_continuous <- mpg |>
  ggplot(aes(x = displ, y = hwy)) +
  geom_point(shape = 21, colour = blends::multiply("#357BA2FF"))

p_discrete_x <- mpg |>
  ggplot(aes(x = drv, y = hwy)) +
  geom_jitter(shape = 21, colour = blends::multiply("#357BA2FF"))

p_discrete_y <- mpg |>
  ggplot(aes(x = hwy, y = drv)) +
  geom_jitter(shape = 21, colour = blends::multiply("#357BA2FF"))
```

``` r
patchwork::wrap_plots(
  p_continuous + classic_drift() + labs(title = "classic_drift"),
  p_discrete_x + classic_drift(discrete = "x"),
  p_discrete_y + classic_drift(discrete = "y"),

  p_continuous + classic_flow() + labs(title = "classic_flow"),
  p_discrete_x + classic_flow(discrete = "x"),
  p_discrete_y + classic_flow(discrete = "y"),

  p_continuous + classic_drop() + labs(title = "classic_drop"),
  p_discrete_x + classic_drop(discrete = "x"),
  p_discrete_y + classic_drop(discrete = "y"),
  
  p_continuous + classic_keep() + labs(title = "classic_keep"),
  p_discrete_x + classic_keep(discrete = "x"),
  p_discrete_y + classic_keep(discrete = "y"),

  ncol = 3
)
```

<img src="man/figures/README-unnamed-chunk-3-1.png" alt="" width="100%" />

``` r
patchwork::wrap_plots(
  p_continuous + modern_drift() + labs(title = "modern_drift"),
  p_discrete_x + modern_drift(discrete = "x"),
  p_discrete_y + modern_drift(discrete = "y"),

  p_continuous + modern_flow() + labs(title = "modern_flow"),
  p_discrete_x + modern_flow(discrete = "x"),
  p_discrete_y + modern_flow(discrete = "y"),

  p_continuous + modern_drop() + labs(title = "modern_drop"),
  p_discrete_x + modern_drop(discrete = "x"),
  p_discrete_y + modern_drop(discrete = "y"),

  p_continuous + modern_keep() + labs(title = "modern_keep"),
  p_discrete_x + modern_keep(discrete = "x"),
  p_discrete_y + modern_keep(discrete = "y"),

  ncol = 3
)
```

<img src="man/figures/README-unnamed-chunk-4-1.png" alt="" width="100%" />

``` r
patchwork::wrap_plots(
  p_continuous + minimal_drift() + labs(title = "minimal_drift"),
  p_discrete_x + minimal_drift(discrete = "x"),
  p_discrete_y + minimal_drift(discrete = "y"),

  p_continuous + minimal_flow() + labs(title = "minimal_flow"),
  p_discrete_x + minimal_flow(discrete = "x"),
  p_discrete_y + minimal_flow(discrete = "y"),

  p_continuous + minimal_drop() + labs(title = "minimal_drop"),
  p_discrete_x + minimal_drop(discrete = "x"),
  p_discrete_y + minimal_drop(discrete = "y"),
  
  p_continuous + minimal_keep() + labs(title = "minimal_keep"),
  p_discrete_x + minimal_keep(discrete = "x"),
  p_discrete_y + minimal_keep(discrete = "y"),

  ncol = 3
)
```

<img src="man/figures/README-unnamed-chunk-5-1.png" alt="" width="100%" />

``` r
patchwork::wrap_plots(
  p_continuous + void_drift() + labs(title = "void_drift"),
  p_discrete_x + void_drift(discrete = "x"),
  p_discrete_y + void_drift(discrete = "y"),

  p_continuous + void_flow() + labs(title = "void_flow"),
  p_discrete_x + void_flow(discrete = "x"),
  p_discrete_y + void_flow(discrete = "y"),

  p_continuous + void_drop() + labs(title = "void_drop"),
  p_discrete_x + void_drop(discrete = "x"),
  p_discrete_y + void_drop(discrete = "y"),
  
  p_continuous + void_keep() + labs(title = "void_keep"),
  p_discrete_x + void_keep(discrete = "x"),
  p_discrete_y + void_keep(discrete = "y"),

  ncol = 3
)
```

<img src="man/figures/README-unnamed-chunk-6-1.png" alt="" width="100%" />

## Other packages

This package is part of a group of related packages built to extend
[ggplot2](https://ggplot2.tidyverse.org).

<table>

<tr>

<td align="center">

<a href="https://davidhodge931.github.io/ggblanket/"><img src="https://raw.githubusercontent.com/davidhodge931/ggblanket/main/man/figures/logo.svg" width="120" alt="ggblanket"/></a>
</td>

<td align="center">

<a href="https://davidhodge931.github.io/ggrefine/"><img src="https://raw.githubusercontent.com/davidhodge931/ggrefine/main/man/figures/logo.svg" width="120" alt="ggrefine"/></a>
</td>

<td align="center">

<a href="https://davidhodge931.github.io/ggscribe/"><img src="https://raw.githubusercontent.com/davidhodge931/ggscribe/main/man/figures/logo.svg" width="120" alt="ggscribe"/></a>
</td>

<td align="center">

<a href="https://davidhodge931.github.io/ggwidth/"><img src="https://raw.githubusercontent.com/davidhodge931/ggwidth/main/man/figures/logo.svg" width="120" alt="ggwidth"/></a>
</td>

<td align="center">

<a href="https://davidhodge931.github.io/blends/"><img src="https://raw.githubusercontent.com/davidhodge931/blends/main/man/figures/logo.svg" width="120" alt="blends"/></a>
</td>

<td align="center">

<a href="https://davidhodge931.github.io/jumble/"><img src="https://raw.githubusercontent.com/davidhodge931/jumble/main/man/figures/logo.svg" width="120" alt="jumble"/></a>
</td>

</tr>

</table>

#' Move the legend place
#'
#' @description Move the legend position set in the theme to somewhere else.
#'
#' @param legend_place The position of the legend. Either "right", "top" or "bottom".
#' @param ... Require named arguments (and support trailing commas).
#' @param legend_key_fill The fill (and colour) of the legend.key theme element.
#' @param legend_background_fill The fill (and colour) of the legend.background theme element.
#' @param legend_axis_line_colour The colour of the legend.axis.line theme element.
#' @param legend_axis_line_linewidth The linewidth of the legend.axis.line theme element.
#' @param legend_ticks_colour The colour of the legend.ticks theme element.
#' @param legend_ticks_linewidth The linewidth of the legend.ticks theme element.
#' @param legend_ticks_length The legend.ticks.length theme element.
#'
#' @return A ggplot theme object with legend position settings.
#' @noRd
#'
legend_place <- function(
  legend_place = "right",
  ...,
  legend_key_fill = NULL,
  legend_background_fill = NULL,
  legend_axis_line_colour = NULL,
  legend_axis_line_linewidth = NULL,
  legend_ticks_colour = NULL,
  legend_ticks_linewidth = NULL,
  legend_ticks_length = NULL
) {
  if (!legend_place %in% c("right", "top", "bottom")) {
    rlang::abort("legend_place must be 'right', 'top', or 'bottom'")
  }

  current_theme <- ggplot2::get_theme()

  if (is.null(legend_key_fill)) {
    legend_key_fill <- ggplot2::calc_element("legend.key", current_theme)@fill
  }
  if (is.null(legend_background_fill)) {
    legend_background_fill <- ggplot2::calc_element(
      "legend.background",
      current_theme
    )@fill
  }
  if (is.null(legend_axis_line_colour)) {
    legend_axis_line_colour <- ggplot2::calc_element(
      "legend.axis.line",
      current_theme
    )@colour
  }
  if (is.null(legend_axis_line_linewidth)) {
    legend_axis_line_linewidth <- ggplot2::calc_element(
      "legend.axis.line",
      current_theme
    )@linewidth
  }
  if (is.null(legend_ticks_colour)) {
    legend_ticks_colour <- ggplot2::calc_element(
      "legend.ticks",
      current_theme
    )@colour
  }
  if (is.null(legend_ticks_linewidth)) {
    legend_ticks_linewidth <- ggplot2::calc_element(
      "legend.ticks",
      current_theme
    )@linewidth
  }
  if (is.null(legend_ticks_length)) {
    legend_ticks_length <- ggplot2::calc_element(
      "legend.ticks.length",
      current_theme
    )
  }

  if (legend_place == "right") {
    ggplot2::theme(
      # All legend elements for right position
      legend.position = "right",
      legend.justification = c(0, 1),
      legend.location = "panel",
      legend.title.position = "top",
      legend.margin = ggplot2::margin(t = 0, r = 0, b = 0, l = 2.75),
      legend.box = "horizontal",
      legend.box.just = "top",
      legend.box.margin = ggplot2::margin(t = 0, r = -5, b = 0, l = 5),
      legend.title = ggplot2::element_text(
        margin = ggplot2::margin(t = 0, r = 0, b = 5.5, l = 0)
      ),
      legend.byrow = FALSE,
      legend.direction = "vertical",
      legend.spacing = grid::unit(11, "pt"),
      legend.spacing.y = grid::unit(16.50, "pt"),
      legend.spacing.x = NULL,
      legend.key = ggplot2::element_rect(
        colour = legend_key_fill,
        fill = legend_key_fill
      ),
      legend.key.height = ggplot2::rel(1),
      legend.key.width = ggplot2::rel(0.6),
      legend.key.spacing = NULL,
      legend.key.spacing.x = grid::unit(11, "pt"),
      legend.key.spacing.y = grid::unit(3.63, "pt"),
      legend.frame = NULL,
      legend.text = ggplot2::element_text(
        margin = ggplot2::margin(5.5, 0, 5.5, 5.5)
      ),
      legend.axis.line = ggplot2::element_line(
        colour = legend_axis_line_colour,
        linewidth = legend_axis_line_linewidth
      ),
      legend.ticks = ggplot2::element_line(
        colour = legend_ticks_colour,
        linewidth = legend_ticks_linewidth
      ),
      legend.ticks.length = legend_ticks_length,
      legend.box.background = NULL,
      legend.box.spacing = NULL,
      legend.background = ggplot2::element_rect(
        colour = legend_background_fill,
        fill = legend_background_fill
      ),

      plot.title = ggplot2::element_text(margin = ggplot2::margin(b = 5.50)),
      plot.subtitle = ggplot2::element_text(margin = ggplot2::margin(b = 5.50)),

      axis.title.x = ggplot2::element_text(
        margin = ggplot2::margin(t = 0, r = 0, b = 1.87, l = 0)
      ),
      axis.title.x.top = ggplot2::element_text(
        margin = ggplot2::margin(t = 0, r = 0, b = 8.25, l = 0)
      ),
      axis.title.y = ggplot2::element_text(
        margin = ggplot2::margin(t = 0, r = 11, b = 0, l = 0),
        angle = 90
      ),
      axis.title.y.right = ggplot2::element_text(
        margin = ggplot2::margin(t = 0, r = 0, b = 0, l = 5.50),
        angle = -90
      ),
      axis.text.x = ggplot2::element_text(
        vjust = 1,
        margin = ggplot2::margin(t = 5.50, r = 0, b = 8.25, l = 0)
      ), ###
      axis.text.x.top = ggplot2::element_text(
        vjust = 0,
        margin = ggplot2::margin(t = 0, r = 0, b = 5.50, l = 0)
      )
    )
  } else if (legend_place == "top") {
    ggplot2::theme(
      # All legend elements for top position
      legend.position = "top",
      legend.justification = c(0, 0.5),
      legend.location = "plot",
      legend.title.position = "top",
      legend.margin = ggplot2::margin(t = 0, r = 22, b = 0, l = 0),
      legend.box = "vertical",
      legend.box.just = "left",
      legend.box.margin = ggplot2::margin(t = 0, r = 0, b = 5, l = 0),
      legend.title = ggplot2::element_text(
        margin = ggplot2::margin(t = 0, r = 0, b = 5.5, l = 0)
      ),
      legend.byrow = TRUE,
      legend.direction = "horizontal",
      legend.spacing = grid::unit(11, "pt"),
      legend.spacing.y = grid::unit(16.50, "pt"),
      legend.spacing.x = NULL,
      legend.key = ggplot2::element_rect(
        colour = legend_key_fill,
        fill = legend_key_fill
      ),
      legend.key.height = ggplot2::rel(1),
      legend.key.width = ggplot2::rel(0.6),

      legend.key.spacing = NULL,
      legend.key.spacing.x = grid::unit(11, "pt"),
      legend.key.spacing.y = grid::unit(3.63, "pt"),
      legend.frame = NULL,
      legend.text = ggplot2::element_text(
        margin = ggplot2::margin(5.5, 5.5, 5.5, 5.5)
      ),
      legend.axis.line = ggplot2::element_line(
        colour = legend_axis_line_colour,
        linewidth = legend_axis_line_linewidth
      ),
      legend.ticks = ggplot2::element_line(
        colour = legend_ticks_colour,
        linewidth = legend_ticks_linewidth
      ),
      legend.ticks.length = legend_ticks_length,
      legend.box.background = NULL,
      legend.box.spacing = NULL,
      legend.background = ggplot2::element_rect(
        colour = legend_background_fill,
        fill = legend_background_fill
      ),

      plot.title = ggplot2::element_text(margin = ggplot2::margin(b = 5.50)),
      plot.subtitle = ggplot2::element_text(margin = ggplot2::margin(b = 5.50)),

      axis.title.x = ggplot2::element_text(
        margin = ggplot2::margin(t = 0, r = 0, b = 4.62, l = 0)
      ),
      axis.title.x.top = ggplot2::element_text(
        margin = ggplot2::margin(t = 0, r = 0, b = 5.50, l = 0)
      ),
      axis.title.y = ggplot2::element_text(
        margin = ggplot2::margin(t = 0, r = 11, b = 0, l = 0),
        angle = 90
      ),
      axis.title.y.right = ggplot2::element_text(
        margin = ggplot2::margin(t = 0, r = 0, b = 0, l = 5.50),
        angle = -90
      ),
      axis.text.x = ggplot2::element_text(
        vjust = 0.5,
        margin = ggplot2::margin(t = 3.30, r = 0, b = 8.25, l = 0)
      ),
      axis.text.x.top = ggplot2::element_text(
        vjust = 0.5,
        margin = ggplot2::margin(t = 0, r = 0, b = 3.30, l = 0)
      )
    )
  } else if (legend_place == "bottom") {
    ggplot2::theme(
      # All legend elements for bottom position
      legend.position = "bottom",
      legend.justification = c(0, 0.5),
      legend.location = "plot",
      legend.title.position = "top",
      legend.margin = ggplot2::margin(t = 0, r = 22, b = 0, l = 0),
      legend.box = "vertical",
      legend.box.just = "left",
      legend.box.margin = ggplot2::margin(t = 0, r = 0, b = 0, l = 0),
      legend.title = ggplot2::element_text(
        margin = ggplot2::margin(t = 2.75, r = 0, b = 5.50, l = 0)
      ),
      legend.byrow = TRUE,
      legend.direction = "horizontal",
      legend.spacing = grid::unit(11, "pt"),
      legend.spacing.y = grid::unit(16.50, "pt"),
      legend.spacing.x = NULL,
      legend.key = ggplot2::element_rect(
        colour = legend_key_fill,
        fill = legend_key_fill
      ),
      legend.key.height = ggplot2::rel(1),
      legend.key.width = ggplot2::rel(0.6),

      legend.key.spacing = NULL,
      legend.key.spacing.x = grid::unit(11, "pt"),
      legend.key.spacing.y = grid::unit(3.63, "pt"),
      legend.frame = NULL,
      legend.text = ggplot2::element_text(
        margin = ggplot2::margin(5.5, 5.5, 5.5, 5.5)
      ),
      legend.axis.line = ggplot2::element_line(
        colour = legend_axis_line_colour,
        linewidth = legend_axis_line_linewidth
      ),
      legend.ticks = ggplot2::element_line(
        colour = legend_ticks_colour,
        linewidth = legend_ticks_linewidth
      ),
      legend.ticks.length = legend_ticks_length,
      legend.box.background = NULL,
      legend.box.spacing = NULL,
      legend.background = ggplot2::element_rect(
        colour = legend_background_fill,
        fill = legend_background_fill
      ),

      plot.title = ggplot2::element_text(margin = ggplot2::margin(b = 5.50)),
      plot.subtitle = ggplot2::element_text(margin = ggplot2::margin(b = 5.50)),

      axis.title.x = ggplot2::element_text(
        margin = ggplot2::margin(t = 0, r = 0, b = 4.62, l = 0)
      ),
      axis.title.x.top = ggplot2::element_text(
        margin = ggplot2::margin(t = 0, r = 0, b = 5.50, l = 0)
      ),
      axis.title.y = ggplot2::element_text(
        margin = ggplot2::margin(t = 0, r = 11, b = 0, l = 0),
        angle = 90
      ),
      axis.title.y.right = ggplot2::element_text(
        margin = ggplot2::margin(t = 0, r = 0, b = 0, l = 5.50),
        angle = -90
      ),
      axis.text.x = ggplot2::element_text(
        vjust = 1,
        margin = ggplot2::margin(t = 3.30, r = 0, b = 8.25, l = 0)
      ),
      axis.text.x.top = ggplot2::element_text(
        vjust = 0,
        margin = ggplot2::margin(t = 0, r = 0, b = 3.30, l = 0)
      )
    )
  }
}

#' Modern refine
#'
#' Removes gridlines and axis line/tick elements from the non-focused dimension.
#' Also removes ticks on discrete axes.
#'
#' @param x_type Character. Type of x-axis: "continuous", "binned", or "discrete".
#' @param y_type Character. Type of y-axis: "continuous", "binned", or "discrete".
#' @param focus Character. The primary axis of interest: "x" or "y". Gridlines
#'   and axis elements are removed from the opposite axis. If `NULL` (default),
#'   focus is inferred from `x_type` and `y_type`: discrete x with continuous/binned
#'   y gives `"x"`, continuous/binned x with discrete y gives `"y"`, otherwise `"x"`.
#' @param ... Additional arguments (currently unused).
#'
#' @return A ggplot2 theme object
#' @export
#'
#' @examples
#' library(ggplot2)
#'
#' set_theme(new = ggrefine::theme_grey())
#'
#' p_continuous <- mpg |>
#'   ggplot(aes(x = displ, y = hwy)) +
#'   geom_point(shape = 21, colour = blends::multiply("#357BA2FF"))
#'
#' p_discrete_x <- mpg |>
#'   ggplot(aes(x = drv, y = hwy)) +
#'   geom_jitter(shape = 21, colour = blends::multiply("#357BA2FF"))
#'
#' p_discrete_y <- mpg |>
#'   ggplot(aes(x = hwy, y = drv)) +
#'   geom_jitter(shape = 21, colour = blends::multiply("#357BA2FF"))
#'
#' patchwork::wrap_plots(
#'   p_continuous + ggrefine::classic() + labs(title = "ggrefine::classic"),
#'   p_discrete_x + ggrefine::classic(x_type = "discrete"),
#'   p_discrete_y + ggrefine::classic(y_type = "discrete"),
#'   p_continuous + ggrefine::modern() + labs(title = "ggrefine::modern"),
#'   p_discrete_x + ggrefine::modern(x_type = "discrete"),
#'   p_discrete_y + ggrefine::modern(y_type = "discrete"),
#'   p_continuous + ggrefine::hybrid() + labs(title = "ggrefine::hybrid"),
#'   p_discrete_x + ggrefine::hybrid(x_type = "discrete"),
#'   p_discrete_y + ggrefine::hybrid(y_type = "discrete"),
#'   p_continuous + ggrefine::minimal() + labs(title = "ggrefine::minimal"),
#'   p_discrete_x + ggrefine::minimal(x_type = "discrete"),
#'   p_discrete_y + ggrefine::minimal(y_type = "discrete"),
#'   p_continuous + ggrefine::void() + labs(title = "ggrefine::void"),
#'   p_discrete_x + ggrefine::void(x_type = "discrete"),
#'   p_discrete_y + ggrefine::void(y_type = "discrete"),
#'   p_continuous + ggrefine::none() + labs(title = "ggrefine::none"),
#'   p_discrete_x + ggrefine::none(x_type = "discrete"),
#'   p_discrete_y + ggrefine::none(y_type = "discrete"),
#'   ncol = 3
#' )
#'
modern <- function(
    x_type = "continuous",
    y_type = "continuous",
    focus = NULL,
    ...
) {
  rlang::arg_match(x_type, c("continuous", "binned", "discrete"))
  rlang::arg_match(y_type, c("continuous", "binned", "discrete"))

  if (is.null(focus)) {
    if (x_type == "discrete" & y_type %in% c("continuous", "binned")) {
      focus <- "x"
    } else if (x_type %in% c("continuous", "binned") & y_type == "discrete") {
      focus <- "y"
    } else {
      focus <- "x"
    }
  }

  rlang::arg_match(focus, c("x", "y"))

  both_continuous <- x_type %in% c("continuous", "binned") &
    y_type %in% c("continuous", "binned")

  theme <- ggplot2::theme()

  if (focus == "x") {
    theme <- theme +
      ggplot2::theme(
        axis.line.y.left             = ggplot2::element_line(linetype = 0),
        axis.line.y.right            = ggplot2::element_line(linetype = 0),
        axis.ticks.y.left            = ggplot2::element_line(linetype = 0),
        axis.ticks.y.right           = ggplot2::element_line(linetype = 0),
        axis.minor.ticks.y.left      = ggplot2::element_line(linetype = 0),
        axis.minor.ticks.y.right     = ggplot2::element_line(linetype = 0),
      )
    if (!both_continuous) {
      theme <- theme +
        ggplot2::theme(
          panel.grid.major.x = ggplot2::element_line(linetype = 0),
          panel.grid.minor.x = ggplot2::element_line(linetype = 0)
        )
    }
  }

  if (focus == "y") {
    theme <- theme +
      ggplot2::theme(
        axis.line.x.bottom           = ggplot2::element_line(linetype = 0),
        axis.line.x.top              = ggplot2::element_line(linetype = 0),
        axis.ticks.x.bottom          = ggplot2::element_line(linetype = 0),
        axis.ticks.x.top             = ggplot2::element_line(linetype = 0),
        axis.minor.ticks.x.bottom    = ggplot2::element_line(linetype = 0),
        axis.minor.ticks.x.top       = ggplot2::element_line(linetype = 0),
      )
    if (!both_continuous) {
      theme <- theme +
        ggplot2::theme(
          panel.grid.major.y = ggplot2::element_line(linetype = 0),
          panel.grid.minor.y = ggplot2::element_line(linetype = 0)
        )
    }
  }

  if (x_type == "discrete") {
    theme <- theme +
      ggplot2::theme(
        axis.ticks.x.bottom = ggplot2::element_line(linetype = 0),
        axis.ticks.x.top    = ggplot2::element_line(linetype = 0),
      )
  }
  if (y_type == "discrete") {
    theme <- theme +
      ggplot2::theme(
        axis.ticks.y.left  = ggplot2::element_line(linetype = 0),
        axis.ticks.y.right = ggplot2::element_line(linetype = 0),
      )
  }

  return(theme)
}

#' classic refine
#'
#' Removes gridlines and ticks from discrete axes.
#'
#' @inheritParams modern
#'
#' @return A ggplot2 theme object
#' @export
#'
#' @inherit modern examples
#'
classic <- function(
    x_type = "continuous",
    y_type = "continuous",
    focus = NULL,
    ...
) {
  rlang::arg_match(x_type, c("continuous", "binned", "discrete"))
  rlang::arg_match(y_type, c("continuous", "binned", "discrete"))

  if (is.null(focus)) {
    if (x_type == "discrete" & y_type %in% c("continuous", "binned")) {
      focus <- "x"
    } else if (x_type %in% c("continuous", "binned") & y_type == "discrete") {
      focus <- "y"
    } else {
      focus <- "x"
    }
  }

  rlang::arg_match(focus, c("x", "y"))

  theme <- ggplot2::theme()

  if (x_type == "discrete") {
    theme <- theme +
      ggplot2::theme(
        axis.ticks.x.bottom = ggplot2::element_line(linetype = 0),
        axis.ticks.x.top = ggplot2::element_line(linetype = 0),
        panel.grid.major.x = ggplot2::element_line(linetype = 0),
        panel.grid.minor.x = ggplot2::element_line(linetype = 0)
      )
  }

  if (y_type == "discrete") {
    theme <- theme +
      ggplot2::theme(
        axis.ticks.y.left = ggplot2::element_line(linetype = 0),
        axis.ticks.y.right = ggplot2::element_line(linetype = 0),
        panel.grid.major.y = ggplot2::element_line(linetype = 0),
        panel.grid.minor.y = ggplot2::element_line(linetype = 0)
      )
  }

  return(theme)
}

#' Hybrid refine
#'
#' Behaves like [ggrefine::classic()] when both axes are continuous or binned —
#' leaving gridlines and axis elements untouched. When a discrete axis is
#' present, behaves like [ggrefine::modern()], removing gridlines and axis
#' line/tick elements from the non-focused dimension and stripping ticks from
#' the discrete axis.
#'
#' @inheritParams modern
#'
#' @return A ggplot2 theme object
#' @export
#'
#' @inherit modern examples
#'
hybrid <- function(
    x_type = "continuous",
    y_type = "continuous",
    focus = NULL,
    ...
) {
  rlang::arg_match(x_type, c("continuous", "binned", "discrete"))
  rlang::arg_match(y_type, c("continuous", "binned", "discrete"))

  if (is.null(focus)) {
    if (x_type == "discrete" & y_type %in% c("continuous", "binned")) {
      focus <- "x"
    } else if (x_type %in% c("continuous", "binned") & y_type == "discrete") {
      focus <- "y"
    } else {
      focus <- "x"
    }
  }

  rlang::arg_match(focus, c("x", "y"))

  both_continuous <- x_type %in% c("continuous", "binned") &
    y_type %in% c("continuous", "binned")

  if (both_continuous) {
    return(ggplot2::theme())
  }

  modern(x_type = x_type, y_type = y_type, focus = focus)
}

#' Minimal refine
#'
#' Behaves like [ggrefine::hybrid()] but additionally removes axis lines and
#' ticks from both axes. When both axes are continuous or binned, only axis
#' lines and ticks are removed, leaving gridlines untouched. When a discrete
#' axis is present, also removes gridlines and axis elements from the
#' non-focused dimension, as in [ggrefine::modern()].
#'
#' @inheritParams modern
#'
#' @return A ggplot2 theme object
#' @export
#'
#' @inherit modern examples
#'
minimal <- function(
    x_type = "continuous",
    y_type = "continuous",
    focus = NULL,
    ...
) {
  rlang::arg_match(x_type, c("continuous", "binned", "discrete"))
  rlang::arg_match(y_type, c("continuous", "binned", "discrete"))

  if (is.null(focus)) {
    if (x_type == "discrete" & y_type %in% c("continuous", "binned")) {
      focus <- "x"
    } else if (x_type %in% c("continuous", "binned") & y_type == "discrete") {
      focus <- "y"
    } else {
      focus <- "x"
    }
  }

  rlang::arg_match(focus, c("x", "y"))

  # Strip axis lines and ticks from both axes unconditionally
  base <- ggplot2::theme(
    axis.line.x.bottom         = ggplot2::element_line(linetype = 0),
    axis.line.x.top            = ggplot2::element_line(linetype = 0),
    axis.line.y.left           = ggplot2::element_line(linetype = 0),
    axis.line.y.right          = ggplot2::element_line(linetype = 0),
    axis.ticks.x.bottom        = ggplot2::element_line(linetype = 0),
    axis.ticks.x.top           = ggplot2::element_line(linetype = 0),
    axis.ticks.y.left          = ggplot2::element_line(linetype = 0),
    axis.ticks.y.right         = ggplot2::element_line(linetype = 0),
    axis.minor.ticks.x.bottom  = ggplot2::element_line(linetype = 0),
    axis.minor.ticks.x.top     = ggplot2::element_line(linetype = 0),
    axis.minor.ticks.y.left    = ggplot2::element_line(linetype = 0),
    axis.minor.ticks.y.right   = ggplot2::element_line(linetype = 0),
  )

  both_continuous <- x_type %in% c("continuous", "binned") &
    y_type %in% c("continuous", "binned")

  if (both_continuous) {
    return(base)
  }

  # Discrete axis present — add hybrid/modern gridline removal on top
  base + modern(x_type = x_type, y_type = y_type, focus = focus)
}

#' Dark theme
#'
#' @description A complete theme for a dark plot and panel background.
#'
#' @inheritParams theme_light
#'
#' @return A ggplot theme.
#' @export
#' @inherit theme_light examples
#'
theme_dark <- function(
    ...,
    text_size = 10,
    text_family = "",
    text_colour = flexoki::flexoki$base["base200"],
    legend_place = "right",
    legend_axis_line_colour = plot_background_fill,
    legend_axis_line_linewidth = axis_line_linewidth,
    legend_background_fill = plot_background_fill,
    legend_key_fill = plot_background_fill,
    legend_ticks_colour = legend_axis_line_colour,
    legend_ticks_linewidth = legend_axis_line_linewidth,
    legend_ticks_length = grid::unit(c(2.75, 0), "pt"),
    axis_line_colour = flexoki::flexoki$base["base600"],
    axis_line_linewidth = 0.25,
    axis_ticks_colour = axis_line_colour,
    axis_ticks_linewidth = axis_line_linewidth,
    axis_ticks_length = grid::unit(3.66, "pt"),
    panel_background_fill = flexoki::flexoki$base["base950"],
    panel_grid_colour = "black",
    panel_grid_linetype = 1,
    panel_grid_linewidth = 1,
    panel_grid_minor_linetype = 1,
    panel_grid_minor_linewidth = 0.5,
    plot_background_fill = "black",
    geom_fill = "#357BA2FF",
    geom_colour = geom_fill,
    palette_fill_discrete = jumble::jumble,
    palette_colour_discrete = palette_fill_discrete,
    palette_fill_continuous = viridis::turbo(n = 256),
    palette_colour_continuous = palette_fill_continuous,
    panel_widths = NULL,
    panel_heights = NULL
) {
  theme_light(
    ...,
    text_size = text_size,
    text_family = text_family,
    text_colour = as.character(text_colour),
    legend_place = legend_place,
    legend_axis_line_colour = as.character(legend_axis_line_colour),
    legend_axis_line_linewidth = legend_axis_line_linewidth,
    legend_background_fill = as.character(legend_background_fill),
    legend_key_fill = as.character(legend_key_fill),
    legend_ticks_colour = as.character(legend_ticks_colour),
    legend_ticks_linewidth = legend_ticks_linewidth,
    legend_ticks_length = legend_ticks_length,
    axis_line_colour = as.character(axis_line_colour),
    axis_line_linewidth = axis_line_linewidth,
    axis_ticks_colour = as.character(axis_ticks_colour),
    axis_ticks_linewidth = axis_ticks_linewidth,
    axis_ticks_length = axis_ticks_length,
    plot_background_fill = as.character(plot_background_fill),
    panel_background_fill = as.character(panel_background_fill),
    panel_grid_colour = as.character(panel_grid_colour),
    panel_grid_linetype = panel_grid_linetype,
    panel_grid_linewidth = panel_grid_linewidth,
    panel_grid_minor_linetype = panel_grid_minor_linetype,
    panel_grid_minor_linewidth = panel_grid_minor_linewidth,
    geom_fill = as.character(geom_fill),
    geom_colour = as.character(geom_colour),
    palette_fill_discrete = palette_fill_discrete,
    palette_colour_discrete = palette_colour_discrete,
    palette_fill_continuous = palette_fill_continuous,
    palette_colour_continuous = palette_colour_continuous,
    panel_widths = panel_widths,
    panel_heights = panel_heights
  )
}

#' theme_light------------------------------------------------------------------
#'
#' Light theme
#'
#' @description A complete theme for a white plot and panel background.
#'
#' @param ... Require named arguments (and support trailing commas).
#' @param text_size The base size of the text theme element. Defaults to 10.
#' @param text_family The base family of the text theme element. Defaults to "".
#' @param text_colour The base colour of the text theme element.
#' @param title_size The size of the `plot.title` theme element. Defaults to `text_size`.
#' @param title_family The family of the `plot.title` theme element. Defaults to `text_family`.
#' @param title_colour The colour of the `plot.title` theme element. Defaults to `text_colour`.
#' @param subtitle_size The size of the `plot.subtitle` theme element. Defaults to `text_size`.
#' @param subtitle_family The family of the `plot.subtitle` theme element. Defaults to `text_family`.
#' @param subtitle_colour The colour of the `plot.subtitle` theme element. Defaults to `text_colour`.
#' @param caption_size The size of the `plot.caption` theme element. Defaults to `text_size`.
#' @param caption_family The family of the `plot.caption` theme element. Defaults to `text_family`.
#' @param caption_colour The colour of the `plot.caption` theme element. Defaults to `text_colour`.
#' @param caption_hjust The horizontal justification of the `plot.caption` theme element. Defaults to 0.
#' @param legend_place The place of the legend. Either "right", "top" or "bottom".
#' @param legend_axis_line_colour The colour of the legend.axis.line theme element.
#' @param legend_axis_line_linewidth The linewidth of the legend.axis.line theme element.
#' @param legend_background_fill The fill (and colour) of the `legend.background` theme element.
#' @param legend_key_fill The fill (and colour) of the legend.key theme element.
#' @param legend_ticks_colour The colour of the legend.ticks theme element.
#' @param legend_ticks_linewidth The linewidth of the legend.ticks theme element.
#' @param legend_ticks_length The length of the legend.ticks.length theme element.
#' @param axis_line_colour The colour of the axis.line theme element. Defaults to `text_colour`.
#' @param axis_line_linewidth The linewidth of the axis.line theme element.
#' @param axis_ticks_colour The colour of the axis.ticks theme element.
#' @param axis_ticks_linewidth The linewidth of the axis.ticks theme element.
#' @param axis_ticks_length The length of the axis.ticks.length theme element.
#' @param panel_background_fill The fill (and colour) of the panel.background theme element.
#' @param panel_grid_colour The colour of the panel.grid theme element.
#' @param panel_grid_linetype The linetype of the panel.grid.major theme element.
#' @param panel_grid_linewidth The linewidth of the panel.grid.major theme element.
#' @param panel_grid_minor_linetype The linetype of the panel.grid.minor theme element.
#' @param panel_grid_minor_linewidth The linewidth of the panel.grid.minor theme element.
#' @param plot_background_fill The fill (and colour) of the plot.background theme element.
#' @param panel_widths The panel.widths theme element. A `unit` or unit vector setting the width of
#'   individual panels, or a single unit for the total panel area width. Overrides aspect ratio set
#'   by the theme, coord, or facets. Defaults to `NULL`.
#' @param panel_heights The panel.heights theme element. A `unit` or unit vector setting the height of
#'   individual panels, or a single unit for the total panel area height. Overrides aspect ratio set
#'   by the theme, coord, or facets. Defaults to `NULL`.
#'
#' @return A ggplot theme.
#' @export
theme_light <- function(
  ...,
  text_size = 10,
  text_family = "",
  text_colour = flexoki::flexoki$base["black"],
  title_size = NULL,
  title_family = NULL,
  title_colour = NULL,
  subtitle_size = NULL,
  subtitle_family = NULL,
  subtitle_colour = NULL,
  caption_size = NULL,
  caption_family = NULL,
  caption_colour = NULL,
  caption_hjust = 0,
  legend_place = "right",
  legend_axis_line_colour = NULL,
  legend_axis_line_linewidth = NULL,
  legend_background_fill = NULL,
  legend_key_fill = NULL,
  legend_ticks_colour = NULL,
  legend_ticks_linewidth = NULL,
  legend_ticks_length = grid::unit(c(2.75, 0), "pt"),
  axis_line_colour = NULL,
  axis_line_linewidth = 0.2,
  axis_ticks_colour = NULL,
  axis_ticks_linewidth = NULL,
  axis_ticks_length = grid::unit(3.66, "pt"),
  panel_background_fill = "white",
  panel_grid_colour = flexoki::flexoki$base["base50"],
  panel_grid_linetype = 1,
  panel_grid_linewidth = 1,
  panel_grid_minor_linetype = 1,
  panel_grid_minor_linewidth = 0.5,
  plot_background_fill = "white",
  panel_widths = NULL,
  panel_heights = NULL
) {
  legend_place <- match.arg(legend_place, c("right", "top", "bottom"))

  # Resolve dependent defaults inside the function body to avoid lazy
  # evaluation surprises when arguments inherit from other arguments.
  if (is.null(title_size)) {
    title_size <- text_size
  }
  if (is.null(title_family)) {
    title_family <- text_family
  }
  if (is.null(title_colour)) {
    title_colour <- text_colour
  }

  if (is.null(subtitle_size)) {
    subtitle_size <- text_size
  }
  if (is.null(subtitle_family)) {
    subtitle_family <- text_family
  }
  if (is.null(subtitle_colour)) {
    subtitle_colour <- text_colour
  }

  if (is.null(caption_size)) {
    caption_size <- text_size
  }
  if (is.null(caption_family)) {
    caption_family <- text_family
  }
  if (is.null(caption_colour)) {
    caption_colour <- text_colour
  }

  if (is.null(axis_line_colour)) {
    axis_line_colour <- text_colour
  }

  # Convert all colour arguments to plain character strings
  text_colour <- as.character(text_colour)
  title_colour <- as.character(title_colour)
  subtitle_colour <- as.character(subtitle_colour)
  caption_colour <- as.character(caption_colour)
  axis_line_colour <- as.character(axis_line_colour)
  panel_background_fill <- as.character(panel_background_fill)
  panel_grid_colour <- as.character(panel_grid_colour)
  plot_background_fill <- as.character(plot_background_fill)

  # Set defaults for dependent parameters
  if (is.null(axis_ticks_colour)) {
    axis_ticks_colour <- axis_line_colour
  }
  if (is.null(axis_ticks_linewidth)) {
    axis_ticks_linewidth <- axis_line_linewidth
  }
  if (is.null(legend_axis_line_colour)) {
    legend_axis_line_colour <- plot_background_fill
  }
  if (is.null(legend_axis_line_linewidth)) {
    legend_axis_line_linewidth <- axis_line_linewidth
  }
  if (is.null(legend_background_fill)) {
    legend_background_fill <- plot_background_fill
  }
  if (is.null(legend_key_fill)) {
    legend_key_fill <- plot_background_fill
  }
  if (is.null(legend_ticks_colour)) {
    legend_ticks_colour <- legend_axis_line_colour
  }
  if (is.null(legend_ticks_linewidth)) {
    legend_ticks_linewidth <- legend_axis_line_linewidth
  }

  # Convert dependent colour arguments to plain character strings
  axis_ticks_colour <- as.character(axis_ticks_colour)
  legend_axis_line_colour <- as.character(legend_axis_line_colour)
  legend_background_fill <- as.character(legend_background_fill)
  legend_key_fill <- as.character(legend_key_fill)
  legend_ticks_colour <- as.character(legend_ticks_colour)

  # Base theme (same for all legend positions)
  theme <-
    ggplot2::theme(
      text = ggplot2::element_text(
        size = text_size,
        family = text_family,
        colour = text_colour,
        lineheight = 0.9,
        hjust = 0.5,
        vjust = 0.5,
        angle = 0,
        margin = ggplot2::margin()
      ),
      line = ggplot2::element_line(
        colour = axis_line_colour,
        linewidth = axis_line_linewidth,
        lineend = "butt"
      ),
      axis.line = ggplot2::element_line(
        colour = axis_line_colour,
        linewidth = axis_line_linewidth,
        lineend = "square"
      ),
      axis.line.x = NULL,
      axis.line.x.bottom = NULL,
      axis.line.x.top = NULL,
      axis.line.y = NULL,
      axis.line.y.left = NULL,
      axis.line.y.right = NULL,
      axis.ticks = ggplot2::element_line(
        colour = axis_ticks_colour,
        linewidth = axis_ticks_linewidth,
        lineend = "butt"
      ),
      axis.minor.ticks.x.bottom = ggplot2::element_line(
        colour = axis_ticks_colour
      ),
      axis.minor.ticks.x.top = ggplot2::element_line(
        colour = axis_ticks_colour
      ),
      axis.minor.ticks.y.left = ggplot2::element_line(
        colour = axis_ticks_colour
      ),
      axis.minor.ticks.y.right = ggplot2::element_line(
        colour = axis_ticks_colour
      ),
      axis.ticks.x = NULL,
      axis.ticks.x.top = NULL,
      axis.ticks.x.bottom = NULL,
      axis.ticks.y = NULL,
      axis.ticks.y.left = NULL,
      axis.ticks.y.right = NULL,
      axis.ticks.length = axis_ticks_length,
      axis.ticks.length.x = NULL,
      axis.ticks.length.x.top = NULL,
      axis.ticks.length.x.bottom = NULL,
      axis.ticks.length.y = NULL,
      axis.ticks.length.y.left = NULL,
      axis.ticks.length.y.right = NULL,
      axis.minor.ticks.length = ggplot2::rel(0.66),
      axis.title = ggplot2::element_text(),
      axis.title.x = ggplot2::element_text(
        margin = ggplot2::margin(t = 5.5)
      ),
      axis.title.x.top = ggplot2::element_text(
        margin = ggplot2::margin(b = 5.5)
      ),
      axis.title.y = ggplot2::element_text(
        margin = ggplot2::margin(r = 11),
        angle = 90
      ),
      axis.title.y.right = ggplot2::element_text(
        margin = ggplot2::margin(l = 11),
        angle = -90
      ),
      axis.text = ggplot2::element_text(),
      axis.text.x = ggplot2::element_text(
        vjust = 1,
        margin = ggplot2::margin(t = 3.33)
      ),
      axis.text.x.top = ggplot2::element_text(
        vjust = 0,
        margin = ggplot2::margin(b = 3.33)
      ),
      axis.text.y = ggplot2::element_text(
        margin = ggplot2::margin(r = 3.33),
        hjust = 1
      ),
      axis.text.y.right = ggplot2::element_text(
        margin = ggplot2::margin(l = 3.33),
        hjust = 0
      ),

      legend.key = ggplot2::element_rect(
        colour = legend_key_fill,
        fill = legend_key_fill
      ),
      legend.key.height = ggplot2::rel(1),
      legend.key.width = ggplot2::rel(0.6),

      legend.key.spacing = NULL,
      legend.key.spacing.x = grid::unit(11, "pt"),
      legend.key.spacing.y = grid::unit(3.33, "pt"),
      legend.frame = NULL,
      legend.spacing = ggplot2::unit(5.5, "pt"),
      legend.spacing.y = ggplot2::unit(0, "pt"),
      legend.text = ggplot2::element_text(
        margin = ggplot2::margin(l = 5.5)
      ),
      legend.axis.line = ggplot2::element_line(
        colour = legend_axis_line_colour,
        linewidth = legend_axis_line_linewidth
      ),
      legend.ticks = ggplot2::element_line(
        colour = legend_ticks_colour,
        linewidth = legend_ticks_linewidth
      ),
      legend.ticks.length = legend_ticks_length,
      legend.box.background = NULL,
      legend.box.spacing = NULL,
      legend.box.just = "left",
      legend.background = ggplot2::element_rect(
        colour = legend_background_fill,
        fill = legend_background_fill
      ),

      legend.box = "vertical",
      legend.justification.right = "top",
      legend.justification.top = "left",
      legend.justification.bottom = "left",
      legend.title.position = "top",
      panel.background = ggplot2::element_rect(
        colour = panel_background_fill,
        fill = panel_background_fill
      ),
      panel.border = ggplot2::element_blank(),
      panel.grid = ggplot2::element_line(
        colour = panel_grid_colour,
        lineend = "butt"
      ),
      panel.grid.major = ggplot2::element_line(
        linewidth = panel_grid_linewidth,
        linetype = panel_grid_linetype
      ),
      panel.grid.major.x = NULL,
      panel.grid.major.y = NULL,
      panel.grid.minor = ggplot2::element_line(
        linetype = panel_grid_minor_linetype,
        linewidth = panel_grid_minor_linewidth
      ),
      panel.grid.minor.x = NULL,
      panel.grid.minor.y = NULL,
      panel.spacing = grid::unit(20, "pt"),
      panel.spacing.x = NULL,
      panel.spacing.y = NULL,
      panel.ontop = FALSE,
      panel.widths = panel_widths,
      panel.heights = panel_heights,
      spacing = grid::unit(5.5, "pt"),
      strip.background = ggplot2::element_rect(fill = NA, colour = NA),
      strip.clip = "off",
      strip.text = ggplot2::element_text(
        margin = ggplot2::margin(b = 5.5)
      ),
      strip.text.x = NULL,
      strip.text.x.bottom = ggplot2::element_text(
        margin = ggplot2::margin(t = 5.5)
      ),
      strip.text.y = ggplot2::element_text(
        margin = ggplot2::margin(l = 5.5),
        angle = -90
      ),
      strip.text.y.left = ggplot2::element_text(
        margin = ggplot2::margin(r = 5.5),
        angle = 90
      ),
      strip.placement = "outside",
      strip.placement.x = NULL,
      strip.placement.y = NULL,
      strip.switch.pad.grid = grid::unit(2.75, "pt"),
      strip.switch.pad.wrap = grid::unit(2.75, "pt"),
      plot.background = ggplot2::element_rect(
        colour = plot_background_fill,
        fill = plot_background_fill
      ),
      plot.title = ggplot2::element_text(
        size = title_size,
        family = title_family,
        colour = title_colour,
        hjust = 0,
        margin = ggplot2::margin(b = 5.5)
      ),
      plot.subtitle = ggplot2::element_text(
        size = subtitle_size,
        family = subtitle_family,
        colour = subtitle_colour,
        hjust = 0,
        margin = ggplot2::margin(b = 5.5)
      ),
      plot.caption = ggplot2::element_text(
        size = caption_size,
        family = caption_family,
        colour = caption_colour,
        hjust = caption_hjust,
        margin = ggplot2::margin(t = 5.5)
      ),
      plot.title.position = "plot",
      plot.caption.position = "plot",
      plot.tag = ggplot2::element_text(
        size = ggplot2::rel(1.2),
        hjust = 0,
        vjust = 0.5
      ),
      plot.tag.position = "topleft",
      plot.margin = ggplot2::margin(8.25, 12.375, 8.25, 8.25),
      complete = TRUE
    ) +
    ggplot2::theme(
      geom = ggplot2::element_geom(
        fill = "#357BA2FF",
        colour = "#357BA2FF",
        pointshape = 21,
        linewidth = 0.66,
        borderwidth = 0.33,
        pointsize = 1.5,
        fontsize = text_size,
        family = text_family
      ),
      # Border geoms — have both fill and colour
      geom.area = ggplot2::element_geom(linewidth = 0.33, borderwidth = 0.33),
      geom.bar = ggplot2::element_geom(linewidth = 0.33, borderwidth = 0.33),
      geom.boxplot = ggplot2::element_geom(
        linewidth = 0.33,
        borderwidth = 0.33
      ),
      geom.col = ggplot2::element_geom(linewidth = 0.33, borderwidth = 0.33),
      geom.crossbar = ggplot2::element_geom(
        linewidth = 0.33,
        borderwidth = 0.33
      ),
      geom.density = ggplot2::element_geom(
        linewidth = 0.33,
        borderwidth = 0.33
      ),
      geom.dotplot = ggplot2::element_geom(
        linewidth = 0.33,
        borderwidth = 0.33
      ),
      geom.hex = ggplot2::element_geom(linewidth = 0.33, borderwidth = 0.33),
      geom.map = ggplot2::element_geom(linewidth = 0.33, borderwidth = 0.33),
      geom.point = ggplot2::element_geom(linewidth = 0.33, borderwidth = 0.33),
      geom.pointrange = ggplot2::element_geom(
        linewidth = 0.33,
        borderwidth = 0.33
      ),
      geom.polygon = ggplot2::element_geom(
        linewidth = 0.33,
        borderwidth = 0.33
      ),
      geom.rect = ggplot2::element_geom(linewidth = 0.33, borderwidth = 0.33),
      geom.ribbon = ggplot2::element_geom(linewidth = 0.33, borderwidth = 0.33),
      geom.smooth = ggplot2::element_geom(linewidth = 0.33, borderwidth = 0.33),
      geom.sf = ggplot2::element_geom(linewidth = 0.33, borderwidth = 0.33),
      geom.tile = ggplot2::element_geom(linewidth = 0.33, borderwidth = 0.33),
      geom.violin = ggplot2::element_geom(linewidth = 0.33, borderwidth = 0.33),

      # Line geoms — colour only
      geom.abline = ggplot2::element_geom(linewidth = 0.66),
      geom.contour = ggplot2::element_geom(linewidth = 0.66),
      geom.curve = ggplot2::element_geom(linewidth = 0.66),
      geom.density_2d = ggplot2::element_geom(linewidth = 0.66),
      geom.errorbar = ggplot2::element_geom(linewidth = 0.66),
      geom.hline = ggplot2::element_geom(linewidth = 0.66),
      geom.line = ggplot2::element_geom(linewidth = 0.66),
      geom.linerange = ggplot2::element_geom(linewidth = 0.66),
      geom.path = ggplot2::element_geom(linewidth = 0.66),
      geom.quantile = ggplot2::element_geom(linewidth = 0.66),
      geom.rug = ggplot2::element_geom(linewidth = 0.66),
      geom.segment = ggplot2::element_geom(linewidth = 0.66),
      geom.spoke = ggplot2::element_geom(linewidth = 0.66),
      geom.step = ggplot2::element_geom(linewidth = 0.66),
      geom.vline = ggplot2::element_geom(linewidth = 0.66),

      geom.text = ggplot2::element_geom(colour = text_colour),
      geom.label = ggplot2::element_geom(
        colour = text_colour,
        fill = panel_background_fill
      ),

      palette.colour.discrete = jumble::jumble,
      palette.fill.discrete = jumble::jumble,

      palette.colour.continuous = viridis::turbo(n = 256),
      palette.fill.continuous = viridis::turbo(n = 256),

      palette.shape.discrete = scales::pal_manual(c(21, 24, 22, 23, 25)),

      palette.linetype.discrete = scales::pal_manual(1:6)
    )

  if (legend_place == "right") {
    theme +
      ggplot2::theme(
        legend.position = "right",
        legend.location = "panel",
        legend.margin = ggplot2::margin(l = 5.5, b = 11)
      )
  } else if (legend_place == "top") {
    theme +
      ggplot2::theme(
        legend.position = "top",
        legend.location = "plot",
        legend.margin = ggplot2::margin(r = 5.5, b = 11)
      )
  } else if (legend_place == "bottom") {
    theme +
      ggplot2::theme(
        legend.position = "bottom",
        legend.location = "plot",
        legend.margin = ggplot2::margin(r = 5.5, b = 11)
      )
  }
}

#' theme_ggplot2----------------------------------------------------------------
#'
#' Ggplot2 theme
#'
#' @description A complete theme for a coloured panel background on a white plot
#'   background. Defaults to using a panel grid colour that mixes 1/4 panel
#'   background fill with 3/4 white.
#'
#' @inheritParams theme_light
#'
#' @return A ggplot theme.
#' @export
theme_ggplot2 <- function(
  ...,
  text_size = 10,
  text_family = "",
  text_colour = flexoki::flexoki$base["black"],
  title_size = NULL,
  title_family = NULL,
  title_colour = NULL,
  subtitle_size = NULL,
  subtitle_family = NULL,
  subtitle_colour = NULL,
  caption_size = NULL,
  caption_family = NULL,
  caption_colour = NULL,
  caption_hjust = 0,
  legend_place = "right",
  legend_axis_line_colour = NULL,
  legend_axis_line_linewidth = NULL,
  legend_background_fill = NULL,
  legend_key_fill = NULL,
  legend_ticks_colour = NULL,
  legend_ticks_linewidth = NULL,
  legend_ticks_length = grid::unit(c(2.75, 0), "pt"),
  axis_line_colour = NULL,
  axis_line_linewidth = 0.2,
  axis_ticks_colour = NULL,
  axis_ticks_linewidth = NULL,
  axis_ticks_length = grid::unit(3.66, "pt"),
  # panel_background_fill = "#f1efe6ff",
  panel_background_fill = scales::col_mix(
    flexoki::flexoki$base["base100"],
    "white",
    0.5
  ),
  panel_grid_colour = NULL,
  panel_grid_linetype = 1,
  panel_grid_linewidth = 1,
  panel_grid_minor_linetype = 1,
  panel_grid_minor_linewidth = 0.5,
  plot_background_fill = "white",
  panel_widths = NULL,
  panel_heights = NULL
) {
  # Handle defaults dynamically to prevent lazy evaluation conflicts
  if (is.null(panel_grid_colour)) {
    panel_grid_colour <- scales::col_mix(panel_background_fill, "white", 0.75)
  }

  theme_light(
    ...,
    text_size = text_size,
    text_family = text_family,
    text_colour = text_colour,
    title_size = title_size,
    title_family = title_family,
    title_colour = title_colour,
    subtitle_size = subtitle_size,
    subtitle_family = subtitle_family,
    subtitle_colour = subtitle_colour,
    caption_size = caption_size,
    caption_family = caption_family,
    caption_colour = caption_colour,
    caption_hjust = caption_hjust,
    legend_place = legend_place,
    legend_axis_line_colour = legend_axis_line_colour,
    legend_axis_line_linewidth = legend_axis_line_linewidth,
    legend_background_fill = legend_background_fill,
    legend_key_fill = legend_key_fill,
    legend_ticks_colour = legend_ticks_colour,
    legend_ticks_linewidth = legend_ticks_linewidth,
    legend_ticks_length = legend_ticks_length,
    axis_line_colour = axis_line_colour,
    axis_line_linewidth = axis_line_linewidth,
    axis_ticks_colour = axis_ticks_colour,
    axis_ticks_linewidth = axis_ticks_linewidth,
    axis_ticks_length = axis_ticks_length,
    plot_background_fill = plot_background_fill,
    panel_background_fill = panel_background_fill,
    panel_grid_colour = panel_grid_colour,
    panel_grid_linetype = panel_grid_linetype,
    panel_grid_linewidth = panel_grid_linewidth,
    panel_grid_minor_linetype = panel_grid_minor_linetype,
    panel_grid_minor_linewidth = panel_grid_minor_linewidth,
    panel_widths = panel_widths,
    panel_heights = panel_heights
  )
}

#' theme_grey-----------------------------------------------------------------
#'
#' Grey theme
#'
#' @description A complete theme for a coloured panel background on a white plot
#'   background. Defaults to using a panel grid colour that multiply blends the
#'   panel background fill with itself.
#'
#' @inheritParams theme_light
#'
#' @return A ggplot theme.
#' @export
theme_grey <- function(
  ...,
  text_size = 10,
  text_family = "",
  text_colour = flexoki::flexoki$base["black"],
  title_size = NULL,
  title_family = NULL,
  title_colour = NULL,
  subtitle_size = NULL,
  subtitle_family = NULL,
  subtitle_colour = NULL,
  caption_size = NULL,
  caption_family = NULL,
  caption_colour = NULL,
  caption_hjust = 0,
  legend_place = "right",
  legend_axis_line_colour = NULL,
  legend_axis_line_linewidth = NULL,
  legend_background_fill = NULL,
  legend_key_fill = NULL,
  legend_ticks_colour = NULL,
  legend_ticks_linewidth = NULL,
  legend_ticks_length = grid::unit(c(2.75, 0), "pt"),
  axis_line_colour = NULL,
  axis_line_linewidth = 0.2,
  axis_ticks_colour = NULL,
  axis_ticks_linewidth = NULL,
  axis_ticks_length = grid::unit(3.66, "pt"),
  # panel_background_fill = "#f1efe6ff",
  panel_background_fill = scales::col_mix(
    flexoki::flexoki$base["base100"],
    "white",
    0.5
  ),
  panel_grid_colour = NULL,
  panel_grid_linetype = 1,
  panel_grid_linewidth = 1,
  panel_grid_minor_linetype = 1,
  panel_grid_minor_linewidth = 0.5,
  plot_background_fill = "white",
  panel_widths = NULL,
  panel_heights = NULL
) {
  # Handle defaults dynamically to prevent lazy evaluation conflicts
  if (is.null(panel_grid_colour)) {
    panel_grid_colour <- blends::multiply(panel_background_fill)
  }

  theme_light(
    ...,
    text_size = text_size,
    text_family = text_family,
    text_colour = text_colour,
    title_size = title_size,
    title_family = title_family,
    title_colour = title_colour,
    subtitle_size = subtitle_size,
    subtitle_family = subtitle_family,
    subtitle_colour = subtitle_colour,
    caption_size = caption_size,
    caption_family = caption_family,
    caption_colour = caption_colour,
    caption_hjust = caption_hjust,
    legend_place = legend_place,
    legend_axis_line_colour = legend_axis_line_colour,
    legend_axis_line_linewidth = legend_axis_line_linewidth,
    legend_background_fill = legend_background_fill,
    legend_key_fill = legend_key_fill,
    legend_ticks_colour = legend_ticks_colour,
    legend_ticks_linewidth = legend_ticks_linewidth,
    legend_ticks_length = legend_ticks_length,
    axis_line_colour = axis_line_colour,
    axis_line_linewidth = axis_line_linewidth,
    axis_ticks_colour = axis_ticks_colour,
    axis_ticks_linewidth = axis_ticks_linewidth,
    axis_ticks_length = axis_ticks_length,
    plot_background_fill = plot_background_fill,
    panel_background_fill = panel_background_fill,
    panel_grid_colour = panel_grid_colour,
    panel_grid_linetype = panel_grid_linetype,
    panel_grid_linewidth = panel_grid_linewidth,
    panel_grid_minor_linetype = panel_grid_minor_linetype,
    panel_grid_minor_linewidth = panel_grid_minor_linewidth,
    panel_widths = panel_widths,
    panel_heights = panel_heights
  )
}

#' theme_dark------------------------------------------------------------------
#'
#' Dark theme
#'
#' @description A complete theme for a dark plot and panel background. The plot
#'   background defaults to `"black"`, and the panel grid colour defaults to
#'   `plot_background_fill`.
#'
#' @inheritParams theme_light
#'
#' @return A ggplot theme.
#' @export
theme_dark <- function(
  ...,
  text_size = 10,
  text_family = "",
  text_colour = flexoki::flexoki$base["base200"],
  title_size = NULL,
  title_family = NULL,
  title_colour = NULL,
  subtitle_size = NULL,
  subtitle_family = NULL,
  subtitle_colour = NULL,
  caption_size = NULL,
  caption_family = NULL,
  caption_colour = NULL,
  caption_hjust = 0,
  legend_place = "right",
  legend_axis_line_colour = NULL,
  legend_axis_line_linewidth = NULL,
  legend_background_fill = NULL,
  legend_key_fill = NULL,
  legend_ticks_colour = NULL,
  legend_ticks_linewidth = NULL,
  legend_ticks_length = grid::unit(c(2.75, 0), "pt"),
  axis_line_colour = NULL,
  axis_line_linewidth = 0.2,
  axis_ticks_colour = NULL,
  axis_ticks_linewidth = NULL,
  axis_ticks_length = grid::unit(3.66, "pt"),
  # panel_background_fill = scales::col_mix(
  #   flexoki::flexoki$base["base900"],
  #   flexoki::flexoki$base["base950"]
  # ),
  panel_background_fill = flexoki::flexoki$base["base950"],
  panel_grid_colour = NULL,
  panel_grid_linetype = 1,
  panel_grid_linewidth = 1,
  panel_grid_minor_linetype = 1,
  panel_grid_minor_linewidth = 0.5,
  plot_background_fill = "black",
  panel_widths = NULL,
  panel_heights = NULL
) {
  if (is.null(panel_grid_colour)) {
    panel_grid_colour <- plot_background_fill
  }

  theme_light(
    ...,
    text_size = text_size,
    text_family = text_family,
    text_colour = text_colour,
    title_size = title_size,
    title_family = title_family,
    title_colour = title_colour,
    subtitle_size = subtitle_size,
    subtitle_family = subtitle_family,
    subtitle_colour = subtitle_colour,
    caption_size = caption_size,
    caption_family = caption_family,
    caption_colour = caption_colour,
    caption_hjust = caption_hjust,
    legend_place = legend_place,
    legend_axis_line_colour = legend_axis_line_colour,
    legend_axis_line_linewidth = legend_axis_line_linewidth,
    legend_background_fill = legend_background_fill,
    legend_key_fill = legend_key_fill,
    legend_ticks_colour = legend_ticks_colour,
    legend_ticks_linewidth = legend_ticks_linewidth,
    legend_ticks_length = legend_ticks_length,
    axis_line_colour = axis_line_colour,
    axis_line_linewidth = axis_line_linewidth,
    axis_ticks_colour = axis_ticks_colour,
    axis_ticks_linewidth = axis_ticks_linewidth,
    axis_ticks_length = axis_ticks_length,
    plot_background_fill = plot_background_fill,
    panel_background_fill = panel_background_fill,
    panel_grid_colour = panel_grid_colour,
    panel_grid_linetype = panel_grid_linetype,
    panel_grid_linewidth = panel_grid_linewidth,
    panel_grid_minor_linetype = panel_grid_minor_linetype,
    panel_grid_minor_linewidth = panel_grid_minor_linewidth,
    panel_widths = panel_widths,
    panel_heights = panel_heights
  )
}

# ------------------------------------------------------------------------------
# Internal helpers
# ------------------------------------------------------------------------------

.infer_orientation <- function(discrete) {
  if (discrete == "x") {
    "x"
  } else if (discrete == "y") {
    "y"
  } else {
    "x"
  }
}

.validate_refine_args <- function(discrete, orientation) {
  discrete <- rlang::arg_match(discrete, c("none", "x", "y", "both"))

  if (is.null(orientation)) {
    orientation <- .infer_orientation(discrete)
  }

  orientation <- rlang::arg_match(orientation, c("x", "y"))

  list(
    discrete = discrete,
    orientation = orientation
  )
}

# ------------------------------------------------------------------------------
# Theme fragments
# ------------------------------------------------------------------------------

.remove_x_panel_grid <- function() {
  ggplot2::theme(
    panel.grid.major.x = ggplot2::element_line(linetype = 0),
    panel.grid.minor.x = ggplot2::element_line(linetype = 0)
  )
}

.remove_y_panel_grid <- function() {
  ggplot2::theme(
    panel.grid.major.y = ggplot2::element_line(linetype = 0),
    panel.grid.minor.y = ggplot2::element_line(linetype = 0)
  )
}

.remove_x_axis_line <- function() {
  ggplot2::theme(
    axis.line.x.bottom = ggplot2::element_line(linetype = 0),
    axis.line.x.top = ggplot2::element_line(linetype = 0)
  )
}

.remove_y_axis_line <- function() {
  ggplot2::theme(
    axis.line.y.left = ggplot2::element_line(linetype = 0),
    axis.line.y.right = ggplot2::element_line(linetype = 0)
  )
}

.remove_x_axis_ticks <- function() {
  ggplot2::theme(
    axis.ticks.x.bottom = ggplot2::element_line(linetype = 0),
    axis.ticks.x.top = ggplot2::element_line(linetype = 0),
    axis.minor.ticks.x.bottom = ggplot2::element_line(linetype = 0),
    axis.minor.ticks.x.top = ggplot2::element_line(linetype = 0)
  )
}

.remove_y_axis_ticks <- function() {
  ggplot2::theme(
    axis.ticks.y.left = ggplot2::element_line(linetype = 0),
    axis.ticks.y.right = ggplot2::element_line(linetype = 0),
    axis.minor.ticks.y.left = ggplot2::element_line(linetype = 0),
    axis.minor.ticks.y.right = ggplot2::element_line(linetype = 0)
  )
}

.remove_x_axis_text <- function() {
  ggplot2::theme(
    axis.text.x.top = ggplot2::element_blank(),
    axis.text.x.bottom = ggplot2::element_blank()
  )
}

.remove_y_axis_text <- function() {
  ggplot2::theme(
    axis.text.y.left = ggplot2::element_blank(),
    axis.text.y.right = ggplot2::element_blank()
  )
}

.remove_x_axis_title <- function() {
  ggplot2::theme(
    axis.title.x.top = ggplot2::element_blank(),
    axis.title.x.bottom = ggplot2::element_blank()
  )
}

.remove_y_axis_title <- function() {
  ggplot2::theme(
    axis.title.y.left = ggplot2::element_blank(),
    axis.title.y.right = ggplot2::element_blank()
  )
}

# ------------------------------------------------------------------------------
# Axis policies (prefixes)
# ------------------------------------------------------------------------------

.apply_axis_policy <- function(theme, axis_mode, discrete, orientation) {
  axis_mode <- rlang::arg_match(
    axis_mode,
    c("classic", "modern", "minimal", "void")
  )

  if (axis_mode == "classic") {
    if (discrete %in% c("x", "both")) {
      theme <- theme + .remove_x_axis_ticks()
    }

    if (discrete %in% c("y", "both")) {
      theme <- theme + .remove_y_axis_ticks()
    }

    return(theme)
  }

  if (axis_mode == "modern") {
    if (orientation == "x") {
      theme <- theme +
        .remove_y_axis_line() +
        .remove_y_axis_ticks()
    }

    if (orientation == "y") {
      theme <- theme +
        .remove_x_axis_line() +
        .remove_x_axis_ticks()
    }

    if (discrete %in% c("x", "both")) {
      theme <- theme + .remove_x_axis_ticks()
    }

    if (discrete %in% c("y", "both")) {
      theme <- theme + .remove_y_axis_ticks()
    }

    return(theme)
  }

  if (axis_mode == "minimal") {
    theme <- theme +
      .remove_x_axis_line() +
      .remove_y_axis_line() +
      .remove_x_axis_ticks() +
      .remove_y_axis_ticks()

    return(theme)
  }

  if (axis_mode == "void") {
    theme <- theme +
      .remove_x_axis_line() +
      .remove_y_axis_line() +
      .remove_x_axis_ticks() +
      .remove_y_axis_ticks() +
      .remove_x_axis_text() +
      .remove_y_axis_text() +
      .remove_x_axis_title() +
      .remove_y_axis_title()

    return(theme)
  }

  theme
}

# ------------------------------------------------------------------------------
# Grid policies (suffixes)
# ------------------------------------------------------------------------------

.apply_grid_policy <- function(theme, grid_mode, discrete, orientation) {
  grid_mode <- rlang::arg_match(
    grid_mode,
    c("keep", "drift", "flow", "drop")
  )

  if (grid_mode == "keep") {
    return(theme)
  }

  if (grid_mode == "drift") {
    if (discrete != "none") {
      if (orientation == "x") {
        theme <- theme + .remove_x_panel_grid()
      }

      if (orientation == "y") {
        theme <- theme + .remove_y_panel_grid()
      }
    }

    return(theme)
  }

  if (grid_mode == "flow") {
    if (orientation == "x") {
      theme <- theme + .remove_x_panel_grid()
    }

    if (orientation == "y") {
      theme <- theme + .remove_y_panel_grid()
    }

    return(theme)
  }

  if (grid_mode == "drop") {
    theme <- theme +
      .remove_x_panel_grid() +
      .remove_y_panel_grid()

    return(theme)
  }

  theme
}

# ------------------------------------------------------------------------------
# Composition helper
# ------------------------------------------------------------------------------

.compose_refine <- function(axis_mode, grid_mode, discrete, orientation) {
  args <- .validate_refine_args(discrete = discrete, orientation = orientation)

  theme <- ggplot2::theme()

  theme <- .apply_axis_policy(
    theme = theme,
    axis_mode = axis_mode,
    discrete = args$discrete,
    orientation = args$orientation
  )

  theme <- .apply_grid_policy(
    theme = theme,
    grid_mode = grid_mode,
    discrete = args$discrete,
    orientation = args$orientation
  )

  theme
}

# ------------------------------------------------------------------------------
# Classic family
# ------------------------------------------------------------------------------

#' Classic keep refine
#'
#' Removes axis ticks on discrete axes and leaves panel gridlines unchanged.
#'
#' @param ... Reserved for future extensions. Placed first so later arguments
#'   must be named, and to support trailing commas in calls.
#' @param discrete Character scalar describing which axes should be treated as
#'   discrete for refinement purposes: `"none"`, `"x"`, `"y"`, or `"both"`.
#' @param orientation Character. The primary axis of interest: `"x"` or `"y"`.
#'   This affects grid modes such as `*_drift()` and `*_flow()`. If `NULL`
#'   (default), orientation is inferred from `discrete`: `"y"` gives `"y"`,
#'   otherwise `"x"`.
#'
#' @return A ggplot2 theme object
#' @export
classic_keep <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("classic", "keep", discrete, orientation)
}

#' Classic drift refine
#'
#' Removes axis ticks on discrete axes. Removes panel gridlines on the orientation
#' axis only when at least one axis is discrete.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
classic_drift <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("classic", "drift", discrete, orientation)
}

#' Classic flow refine
#'
#' Removes axis ticks on discrete axes and removes panel gridlines on the
#' orientation axis.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
classic_flow <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("classic", "flow", discrete, orientation)
}

#' Classic drop refine
#'
#' Removes axis ticks on discrete axes and removes all panel gridlines.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
classic_drop <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("classic", "drop", discrete, orientation)
}

# ------------------------------------------------------------------------------
# Modern family
# ------------------------------------------------------------------------------

#' Modern keep refine
#'
#' Removes axis lines, ticks, and minor ticks from the non-orientation axis.
#' Axis ticks on discrete axes are removed. Panel gridlines are left unchanged.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
modern_keep <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("modern", "keep", discrete, orientation)
}

#' Modern drift refine
#'
#' Removes axis lines, ticks, and minor ticks from the non-orientation axis.
#' Axis ticks on discrete axes are removed. Removes panel gridlines on the
#' orientation axis only when at least one axis is discrete.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
modern_drift <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("modern", "drift", discrete, orientation)
}

#' Modern flow refine
#'
#' Removes axis lines, ticks, and minor ticks from the non-orientation axis.
#' Axis ticks on discrete axes are removed. Removes panel gridlines on the
#' orientation axis.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
modern_flow <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("modern", "flow", discrete, orientation)
}

#' Modern drop refine
#'
#' Removes axis lines, ticks, and minor ticks from the non-orientation axis.
#' Axis ticks on discrete axes are removed. Removes all panel gridlines.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
modern_drop <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("modern", "drop", discrete, orientation)
}

# ------------------------------------------------------------------------------
# Minimal family
# ------------------------------------------------------------------------------

#' Minimal keep refine
#'
#' Removes all axis lines, ticks, and minor ticks. Panel gridlines are left
#' unchanged.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
minimal_keep <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("minimal", "keep", discrete, orientation)
}

#' Minimal drift refine
#'
#' Removes all axis lines, ticks, and minor ticks. Removes panel gridlines on
#' the orientation axis only when at least one axis is discrete.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
minimal_drift <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("minimal", "drift", discrete, orientation)
}

#' Minimal flow refine
#'
#' Removes all axis lines, ticks, and minor ticks. Removes panel gridlines on
#' the orientation axis.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
minimal_flow <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("minimal", "flow", discrete, orientation)
}

#' Minimal drop refine
#'
#' Removes all axis lines, ticks, and minor ticks. Removes all panel gridlines.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
minimal_drop <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("minimal", "drop", discrete, orientation)
}

# ------------------------------------------------------------------------------
# Void family
# ------------------------------------------------------------------------------

#' Void keep refine
#'
#' Removes all axis lines, ticks, and minor ticks, and removes all axis text
#' and axis titles. Panel gridlines are left unchanged.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
void_keep <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("void", "keep", discrete, orientation)
}

#' Void drift refine
#'
#' Removes all axis lines, ticks, and minor ticks, and removes all axis text
#' and axis titles. Removes panel gridlines on the orientation axis only when at
#' least one axis is discrete.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
void_drift <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("void", "drift", discrete, orientation)
}

#' Void flow refine
#'
#' Removes all axis lines, ticks, and minor ticks, and removes all axis text
#' and axis titles. Removes panel gridlines on the orientation axis.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
void_flow <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("void", "flow", discrete, orientation)
}

#' Void drop refine
#'
#' Removes all axis lines, ticks, and minor ticks, and removes all axis text
#' and axis titles. Removes all panel gridlines.
#'
#' @inheritParams classic_keep
#'
#' @return A ggplot2 theme object
#' @export
void_drop <- function(
  ...,
  discrete = "none",
  orientation = NULL
) {
  rlang::check_dots_empty0(...)

  .compose_refine("void", "drop", discrete, orientation)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/refine.R
\name{refine_void}
\alias{refine_void}
\title{Void refine}
\usage{
refine_void(x_type = "continuous", y_type = "continuous", focus = NULL, ...)
}
\arguments{
\item{x_type}{Character. Type of x-axis: "continuous", "binned", or "discrete".}

\item{y_type}{Character. Type of y-axis: "continuous", "binned", or "discrete".}

\item{focus}{Character. The primary axis of interest: "x" or "y". Gridlines
and axis elements are removed from the opposite axis. If \code{NULL} (default),
focus is inferred from \code{x_type} and \code{y_type}: discrete x with continuous/binned
y gives \code{"x"}, continuous/binned x with discrete y gives \code{"y"}, otherwise \code{"x"}.}

\item{...}{Additional arguments (currently unused).}
}
\value{
A ggplot2 theme object
}
\description{
Removes axes and gridlines.
}
\examples{
library(ggplot2)

set_theme(new = theme_grey())

p_continuous <- mpg |>
  ggplot(aes(x = displ, y = hwy)) +
  geom_point(shape = 21, colour = blends::multiply("#357BA2FF"))

p_discrete_x <- mpg |>
  ggplot(aes(x = drv, y = hwy)) +
  geom_jitter(shape = 21, colour = blends::multiply("#357BA2FF"))

p_discrete_y <- mpg |>
  ggplot(aes(x = hwy, y = drv)) +
  geom_jitter(shape = 21, colour = blends::multiply("#357BA2FF"))

patchwork::wrap_plots(
  p_continuous + ggrefine::refine_modern() + labs(title = "ggrefine::refine_modern"),
  p_discrete_x + ggrefine::refine_modern(x_type = "discrete"),
  p_discrete_y + ggrefine::refine_modern(y_type = "discrete"),
  p_continuous + ggrefine::refine_classic() + labs(title = "ggrefine::refine_classic"),
  p_discrete_x + ggrefine::refine_classic(x_type = "discrete"),
  p_discrete_y + ggrefine::refine_classic(y_type = "discrete"),
  p_continuous + ggrefine::refine_fusion() + labs(title = "ggrefine::refine_fusion"),
  p_discrete_x + ggrefine::refine_fusion(x_type = "discrete"),
  p_discrete_y + ggrefine::refine_fusion(y_type = "discrete"),
  p_continuous + ggrefine::refine_void() + labs(title = "ggrefine::refine_void"),
  p_discrete_x + ggrefine::refine_void(x_type = "discrete"),
  p_discrete_y + ggrefine::refine_void(y_type = "discrete"),
  p_continuous + ggrefine::refine_none() + labs(title = "ggrefine::refine_none"),
  p_discrete_x + ggrefine::refine_none(x_type = "discrete"),
  p_discrete_y + ggrefine::refine_none(y_type = "discrete"),
  ncol = 3
)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/theme.R
\name{theme_light}
\alias{theme_light}
\title{Lighter theme}
\usage{
theme_light(
  ...,
  text_size = 10,
  text_family = "",
  text_colour = flexoki::flexoki$base["black"],
  legend_place = "right",
  legend_axis_line_colour = NULL,
  legend_axis_line_linewidth = NULL,
  legend_background_fill = NULL,
  legend_key_fill = NULL,
  legend_ticks_colour = NULL,
  legend_ticks_linewidth = NULL,
  legend_ticks_length = grid::unit(c(2.75, 0), "pt"),
  axis_line_colour = flexoki::flexoki$base["base600"],
  axis_line_linewidth = 0.25,
  axis_ticks_colour = NULL,
  axis_ticks_linewidth = NULL,
  axis_ticks_length = grid::unit(3.66, "pt"),
  panel_background_fill = "white",
  panel_grid_colour = flexoki::flexoki$base["base50"],
  panel_grid_linetype = 1,
  panel_grid_linewidth = 1,
  panel_grid_minor_linetype = 1,
  panel_grid_minor_linewidth = 0.5,
  plot_background_fill = "white",
  geom_fill = "#357BA2FF",
  geom_colour = geom_fill,
  palette_fill_discrete = jumble::jumble,
  palette_colour_discrete = palette_fill_discrete,
  palette_fill_continuous = viridis::turbo(n = 256),
  palette_colour_continuous = palette_fill_continuous,
  panel_widths = NULL,
  panel_heights = NULL
)
}
\arguments{
\item{...}{Require named arguments (and support trailing commas).}

\item{text_size}{The base size of the text theme element. Defaults to 10.}

\item{text_family}{The base family of the text theme element. Defaults to "".}

\item{text_colour}{The base colour of the text theme element.}

\item{legend_place}{The place of the legend. Either "right", "top" or "bottom".}

\item{legend_axis_line_colour}{The colour of the legend.axis.line theme element.}

\item{legend_axis_line_linewidth}{The linewidth of the legend.axis.line theme element.}

\item{legend_background_fill}{The fill (and colour) of the legend.background theme element.}

\item{legend_key_fill}{The fill (and colour) of the legend.key theme element.}

\item{legend_ticks_colour}{The colour of the legend.ticks theme element.}

\item{legend_ticks_linewidth}{The linewidth of the legend.ticks theme element.}

\item{legend_ticks_length}{The legend.ticks.length theme element.}

\item{axis_line_colour}{The colour of the axis.line theme element.}

\item{axis_line_linewidth}{The linewidth of the axis.line theme element.}

\item{axis_ticks_colour}{The colour of the axis.ticks theme element.}

\item{axis_ticks_linewidth}{The linewidth of the axis.ticks theme element.}

\item{axis_ticks_length}{The length of the axis.ticks.length theme element.}

\item{panel_background_fill}{The fill (and colour) of the panel.background theme element.}

\item{panel_grid_colour}{The colour of the panel.grid theme element.}

\item{panel_grid_linetype}{The linetype of the panel.grid.major theme element.}

\item{panel_grid_linewidth}{The linewidth of the panel.grid.major theme element.}

\item{panel_grid_minor_linetype}{The linetype of the panel.grid.minor theme element.}

\item{panel_grid_minor_linewidth}{The linewidth of the panel.grid.minor theme element.}

\item{plot_background_fill}{The fill (and colour) of the plot.background theme element.}

\item{geom_fill}{The default fill colour of geom elements.}

\item{geom_colour}{The default border colour of geom elements. Defaults to \code{geom_fill}.}

\item{palette_fill_discrete}{The default discrete fill palette. A function or vector of colours.}

\item{palette_colour_discrete}{The default discrete colour palette. Defaults to \code{palette_fill_discrete}.}

\item{palette_fill_continuous}{The default continuous fill palette. A vector of colours.}

\item{palette_colour_continuous}{The default continuous colour palette. Defaults to \code{palette_fill_continuous}.}

\item{panel_widths}{The panel.widths theme element. A \code{unit} or unit vector setting the width of
individual panels, or a single unit for the total panel area width. Overrides aspect ratio set
by the theme, coord, or facets. Defaults to \code{NULL}.}

\item{panel_heights}{The panel.heights theme element. A \code{unit} or unit vector setting the height of
individual panels, or a single unit for the total panel area height. Overrides aspect ratio set
by the theme, coord, or facets. Defaults to \code{NULL}.}
}
\value{
A ggplot theme.
}
\description{
A complete theme for a white panel background.
}
\examples{
library(ggplot2)

p_base_light <- mpg |>
  ggplot(aes(x = hwy)) +
  geom_histogram(
    stat = "bin", shape = 21,
    colour = blends::multiply("#357BA2FF")
  ) +
  scale_y_continuous(expand = expansion(mult = c(0, 0.05)))

p_base_dark <- mpg |>
  ggplot(aes(x = hwy)) +
  geom_histogram(
    stat = "bin", shape = 21,
    colour = blends::screen("#357BA2FF")
  ) +
  scale_y_continuous(expand = expansion(mult = c(0, 0.05)))

p_light  <- p_base_light + ggrefine::theme_light() + labs(title = "ggrefine::theme_light")
p_dark  <- p_base_dark  + ggrefine::theme_dark() + labs(title = "ggrefine::theme_dark")
p_grey <- p_base_light + ggrefine::theme_grey() + labs(title = "ggrefine::theme_grey")

patchwork::wrap_plots(
  p_light,
  p_dark,
  p_grey
)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/minimal.R
\name{minimal}
\alias{minimal}
\title{Minimal refine}
\usage{
minimal(x_type = "continuous", y_type = "continuous", focus = NULL, ...)
}
\arguments{
\item{x_type}{Character. Type of x-axis: "continuous", "binned", or "discrete".}

\item{y_type}{Character. Type of y-axis: "continuous", "binned", or "discrete".}

\item{focus}{Character. The primary axis of interest: "x" or "y". Gridlines
and axis elements are removed from the opposite axis. If \code{NULL} (default),
focus is inferred from \code{x_type} and \code{y_type}: discrete x with continuous/binned
y gives \code{"x"}, continuous/binned x with discrete y gives \code{"y"}, otherwise \code{"x"}.}

\item{...}{Additional arguments (currently unused).}
}
\value{
A ggplot2 theme object
}
\description{
Behaves like \code{\link[=hybrid]{hybrid()}} but additionally removes axis lines and
ticks from both axes. When both axes are continuous or binned, only axis
lines and ticks are removed, leaving gridlines untouched. When a discrete
axis is present, also removes gridlines and axis elements from the
non-focused dimension, as in \code{\link[=modern]{modern()}}.
}
\examples{
library(ggplot2)

set_theme(new = ggrefine::theme_grey())

p_continuous <- mpg |>
  ggplot(aes(x = displ, y = hwy)) +
  geom_point(shape = 21, colour = blends::multiply("#357BA2FF"))

p_discrete_x <- mpg |>
  ggplot(aes(x = drv, y = hwy)) +
  geom_jitter(shape = 21, colour = blends::multiply("#357BA2FF"))

p_discrete_y <- mpg |>
  ggplot(aes(x = hwy, y = drv)) +
  geom_jitter(shape = 21, colour = blends::multiply("#357BA2FF"))

patchwork::wrap_plots(
  p_continuous + ggrefine::classic() + labs(title = "ggrefine::classic"),
  p_discrete_x + ggrefine::classic(x_type = "discrete"),
  p_discrete_y + ggrefine::classic(y_type = "discrete"),
  p_continuous + ggrefine::modern() + labs(title = "ggrefine::modern"),
  p_discrete_x + ggrefine::modern(x_type = "discrete"),
  p_discrete_y + ggrefine::modern(y_type = "discrete"),
  p_continuous + ggrefine::hybrid() + labs(title = "ggrefine::hybrid"),
  p_discrete_x + ggrefine::hybrid(x_type = "discrete"),
  p_discrete_y + ggrefine::hybrid(y_type = "discrete"),
  p_continuous + ggrefine::minimal() + labs(title = "ggrefine::minimal"),
  p_discrete_x + ggrefine::minimal(x_type = "discrete"),
  p_discrete_y + ggrefine::minimal(y_type = "discrete"),
  p_continuous + ggrefine::void() + labs(title = "ggrefine::void"),
  p_discrete_x + ggrefine::void(x_type = "discrete"),
  p_discrete_y + ggrefine::void(y_type = "discrete"),
  p_continuous + ggrefine::none() + labs(title = "ggrefine::none"),
  p_discrete_x + ggrefine::none(x_type = "discrete"),
  p_discrete_y + ggrefine::none(y_type = "discrete"),
  ncol = 3
)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/theme.R
\name{theme_grey}
\alias{theme_grey}
\title{theme_grey-----------------------------------------------------------------}
\usage{
theme_grey(
  ...,
  text_size = 10,
  text_family = "",
  text_colour = flexoki::flexoki$base["black"],
  title_size = NULL,
  title_family = NULL,
  title_colour = NULL,
  subtitle_size = NULL,
  subtitle_family = NULL,
  subtitle_colour = NULL,
  caption_size = NULL,
  caption_family = NULL,
  caption_colour = NULL,
  caption_hjust = 0,
  legend_place = "right",
  legend_axis_line_colour = NULL,
  legend_axis_line_linewidth = NULL,
  legend_background_fill = NULL,
  legend_key_fill = NULL,
  legend_ticks_colour = NULL,
  legend_ticks_linewidth = NULL,
  legend_ticks_length = grid::unit(c(2.75, 0), "pt"),
  axis_line_colour = NULL,
  axis_line_linewidth = 0.2,
  axis_ticks_colour = NULL,
  axis_ticks_linewidth = NULL,
  axis_ticks_length = grid::unit(3.66, "pt"),
  panel_background_fill = scales::col_mix(flexoki::flexoki$base["base100"], "white", 0.5),
  panel_grid_colour = NULL,
  panel_grid_linetype = 1,
  panel_grid_linewidth = 1,
  panel_grid_minor_linetype = 1,
  panel_grid_minor_linewidth = 0.5,
  plot_background_fill = "white",
  panel_widths = NULL,
  panel_heights = NULL
)
}
\arguments{
\item{...}{Require named arguments (and support trailing commas).}

\item{text_size}{The base size of the text theme element. Defaults to 10.}

\item{text_family}{The base family of the text theme element. Defaults to "".}

\item{text_colour}{The base colour of the text theme element.}

\item{title_size}{The size of the \code{plot.title} theme element. Defaults to \code{text_size}.}

\item{title_family}{The family of the \code{plot.title} theme element. Defaults to \code{text_family}.}

\item{title_colour}{The colour of the \code{plot.title} theme element. Defaults to \code{text_colour}.}

\item{subtitle_size}{The size of the \code{plot.subtitle} theme element. Defaults to \code{text_size}.}

\item{subtitle_family}{The family of the \code{plot.subtitle} theme element. Defaults to \code{text_family}.}

\item{subtitle_colour}{The colour of the \code{plot.subtitle} theme element. Defaults to \code{text_colour}.}

\item{caption_size}{The size of the \code{plot.caption} theme element. Defaults to \code{text_size}.}

\item{caption_family}{The family of the \code{plot.caption} theme element. Defaults to \code{text_family}.}

\item{caption_colour}{The colour of the \code{plot.caption} theme element. Defaults to \code{text_colour}.}

\item{caption_hjust}{The horizontal justification of the \code{plot.caption} theme element. Defaults to 0.}

\item{legend_place}{The place of the legend. Either "right", "top" or "bottom".}

\item{legend_axis_line_colour}{The colour of the legend.axis.line theme element.}

\item{legend_axis_line_linewidth}{The linewidth of the legend.axis.line theme element.}

\item{legend_background_fill}{The fill (and colour) of the \code{legend.background} theme element.}

\item{legend_key_fill}{The fill (and colour) of the legend.key theme element.}

\item{legend_ticks_colour}{The colour of the legend.ticks theme element.}

\item{legend_ticks_linewidth}{The linewidth of the legend.ticks theme element.}

\item{legend_ticks_length}{The length of the legend.ticks.length theme element.}

\item{axis_line_colour}{The colour of the axis.line theme element. Defaults to \code{text_colour}.}

\item{axis_line_linewidth}{The linewidth of the axis.line theme element.}

\item{axis_ticks_colour}{The colour of the axis.ticks theme element.}

\item{axis_ticks_linewidth}{The linewidth of the axis.ticks theme element.}

\item{axis_ticks_length}{The length of the axis.ticks.length theme element.}

\item{panel_background_fill}{The fill (and colour) of the panel.background theme element.}

\item{panel_grid_colour}{The colour of the panel.grid theme element.}

\item{panel_grid_linetype}{The linetype of the panel.grid.major theme element.}

\item{panel_grid_linewidth}{The linewidth of the panel.grid.major theme element.}

\item{panel_grid_minor_linetype}{The linetype of the panel.grid.minor theme element.}

\item{panel_grid_minor_linewidth}{The linewidth of the panel.grid.minor theme element.}

\item{plot_background_fill}{The fill (and colour) of the plot.background theme element.}

\item{panel_widths}{The panel.widths theme element. A \code{unit} or unit vector setting the width of
individual panels, or a single unit for the total panel area width. Overrides aspect ratio set
by the theme, coord, or facets. Defaults to \code{NULL}.}

\item{panel_heights}{The panel.heights theme element. A \code{unit} or unit vector setting the height of
individual panels, or a single unit for the total panel area height. Overrides aspect ratio set
by the theme, coord, or facets. Defaults to \code{NULL}.}
}
\value{
A ggplot theme.
}
\description{
A complete theme for a coloured panel background on a white plot
background. Defaults to using a panel grid colour that multiply blends the
panel background fill with itself.
}
\details{
Grey theme
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/refine.R
\name{void_drift}
\alias{void_drift}
\title{Void drift refine}
\usage{
void_drift(..., discrete = "none", orientation = NULL)
}
\arguments{
\item{...}{Reserved for future extensions. Placed first so later arguments
must be named, and to support trailing commas in calls.}

\item{discrete}{Character scalar describing which axes should be treated as
discrete for refinement purposes: \code{"none"}, \code{"x"}, \code{"y"}, or \code{"both"}.}

\item{orientation}{Character. The primary axis of interest: \code{"x"} or \code{"y"}.
This affects grid modes such as \verb{*_drift()} and \verb{*_flow()}. If \code{NULL}
(default), orientation is inferred from \code{discrete}: \code{"y"} gives \code{"y"},
otherwise \code{"x"}.}
}
\value{
A ggplot2 theme object
}
\description{
Removes all axis lines, ticks, and minor ticks, and removes all axis text
and axis titles. Removes panel gridlines on the orientation axis only when at
least one axis is discrete.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/refine.R
\name{classic_flow}
\alias{classic_flow}
\title{Classic flow refine}
\usage{
classic_flow(..., discrete = "none", orientation = NULL)
}
\arguments{
\item{...}{Reserved for future extensions. Placed first so later arguments
must be named, and to support trailing commas in calls.}

\item{discrete}{Character scalar describing which axes should be treated as
discrete for refinement purposes: \code{"none"}, \code{"x"}, \code{"y"}, or \code{"both"}.}

\item{orientation}{Character. The primary axis of interest: \code{"x"} or \code{"y"}.
This affects grid modes such as \verb{*_drift()} and \verb{*_flow()}. If \code{NULL}
(default), orientation is inferred from \code{discrete}: \code{"y"} gives \code{"y"},
otherwise \code{"x"}.}
}
\value{
A ggplot2 theme object
}
\description{
Removes axis ticks on discrete axes and removes panel gridlines on the
orientation axis.
}
